#include <kdialog.h>
#include <klocale.h>

/********************************************************************************
** Form generated from reading UI file 'groupedit.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GROUPEDIT_H
#define UI_GROUPEDIT_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QPushButton>
#include <QtGui/QSpacerItem>
#include <QtGui/QTableView>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_groupEdit
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *textLabelAvailable;
    QWidget *widget;
    QHBoxLayout *hboxLayout;
    QLabel *label;
    KLineEdit *filterEdit;
    QTableView *availableKeys;
    QHBoxLayout *hboxLayout1;
    QLabel *kActiveLabel1;
    QPushButton *buttonAdd;
    QPushButton *buttonRemove;
    QSpacerItem *spacerItem;
    QTableView *groupKeys;

    void setupUi(QWidget *groupEdit)
    {
        if (groupEdit->objectName().isEmpty())
            groupEdit->setObjectName(QString::fromUtf8("groupEdit"));
        groupEdit->resize(583, 456);
        vboxLayout = new QVBoxLayout(groupEdit);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        textLabelAvailable = new QLabel(groupEdit);
        textLabelAvailable->setObjectName(QString::fromUtf8("textLabelAvailable"));
        QFont font;
        font.setBold(true);
        font.setWeight(75);
        textLabelAvailable->setFont(font);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(textLabelAvailable->sizePolicy().hasHeightForWidth());
        textLabelAvailable->setSizePolicy(sizePolicy);
        textLabelAvailable->setWordWrap(false);

        vboxLayout->addWidget(textLabelAvailable);

        widget = new QWidget(groupEdit);
        widget->setObjectName(QString::fromUtf8("widget"));
        hboxLayout = new QHBoxLayout(widget);
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(widget);
        label->setObjectName(QString::fromUtf8("label"));

        hboxLayout->addWidget(label);

        filterEdit = new KLineEdit(widget);
        filterEdit->setObjectName(QString::fromUtf8("filterEdit"));
        filterEdit->setClearButtonShown(true);

        hboxLayout->addWidget(filterEdit);


        vboxLayout->addWidget(widget);

        availableKeys = new QTableView(groupEdit);
        availableKeys->setObjectName(QString::fromUtf8("availableKeys"));
        availableKeys->setAcceptDrops(true);
        availableKeys->setSortingEnabled(true);
        availableKeys->setDragEnabled(false);
        availableKeys->setAlternatingRowColors(true);
        availableKeys->setSelectionMode(QAbstractItemView::ExtendedSelection);
        availableKeys->setSelectionBehavior(QAbstractItemView::SelectRows);

        vboxLayout->addWidget(availableKeys);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName(QString::fromUtf8("hboxLayout1"));
        kActiveLabel1 = new QLabel(groupEdit);
        kActiveLabel1->setObjectName(QString::fromUtf8("kActiveLabel1"));
        kActiveLabel1->setFont(font);

        hboxLayout1->addWidget(kActiveLabel1);

        buttonAdd = new QPushButton(groupEdit);
        buttonAdd->setObjectName(QString::fromUtf8("buttonAdd"));

        hboxLayout1->addWidget(buttonAdd);

        buttonRemove = new QPushButton(groupEdit);
        buttonRemove->setObjectName(QString::fromUtf8("buttonRemove"));

        hboxLayout1->addWidget(buttonRemove);

        spacerItem = new QSpacerItem(71, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacerItem);


        vboxLayout->addLayout(hboxLayout1);

        groupKeys = new QTableView(groupEdit);
        groupKeys->setObjectName(QString::fromUtf8("groupKeys"));
        groupKeys->setAcceptDrops(true);
        groupKeys->setSortingEnabled(true);
        groupKeys->setDragEnabled(false);
        groupKeys->setAlternatingRowColors(true);
        groupKeys->setSelectionMode(QAbstractItemView::ExtendedSelection);
        groupKeys->setSelectionBehavior(QAbstractItemView::SelectRows);

        vboxLayout->addWidget(groupKeys);


        retranslateUi(groupEdit);

        QMetaObject::connectSlotsByName(groupEdit);
    } // setupUi

    void retranslateUi(QWidget *groupEdit)
    {
        label->setText(tr2i18n("Search:", 0));
        kActiveLabel1->setText(tr2i18n("Keys in the Group", 0));
        buttonAdd->setText(QString());
        buttonRemove->setText(QString());
        Q_UNUSED(groupEdit);
    } // retranslateUi

};

namespace Ui {
    class groupEdit: public Ui_groupEdit {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GROUPEDIT_H

