#include <kdialog.h>
#include <klocale.h>

/********************************************************************************
** Form generated from reading UI file 'keyexport.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KEYEXPORT_H
#define UI_KEYEXPORT_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QGroupBox>
#include <QtGui/QHeaderView>
#include <QtGui/QRadioButton>
#include <QtGui/QSpacerItem>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include "kcombobox.h"
#include "kpushbutton.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_KeyExport
{
public:
    QVBoxLayout *vboxLayout;
    QWidget *widget;
    QVBoxLayout *verticalLayout;
    QGroupBox *buttonGroup2;
    QVBoxLayout *vboxLayout1;
    QRadioButton *checkMail;
    QRadioButton *checkClipboard;
    QRadioButton *checkServer;
    KComboBox *destServer;
    QRadioButton *checkFile;
    KUrlRequester *newFilename;
    QGroupBox *buttonGroup3;
    QVBoxLayout *vboxLayout2;
    QRadioButton *checkAttrAll;
    QRadioButton *checkAttrPhoto;
    QRadioButton *checkAttrClean;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *KeyExport)
    {
        if (KeyExport->objectName().isEmpty())
            KeyExport->setObjectName(QString::fromUtf8("KeyExport"));
        KeyExport->resize(626, 411);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(KeyExport->sizePolicy().hasHeightForWidth());
        KeyExport->setSizePolicy(sizePolicy);
        KeyExport->setMinimumSize(QSize(350, 0));
        vboxLayout = new QVBoxLayout(KeyExport);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        widget = new QWidget(KeyExport);
        widget->setObjectName(QString::fromUtf8("widget"));
        verticalLayout = new QVBoxLayout(widget);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        buttonGroup2 = new QGroupBox(widget);
        buttonGroup2->setObjectName(QString::fromUtf8("buttonGroup2"));
        vboxLayout1 = new QVBoxLayout(buttonGroup2);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        checkMail = new QRadioButton(buttonGroup2);
        checkMail->setObjectName(QString::fromUtf8("checkMail"));

        vboxLayout1->addWidget(checkMail);

        checkClipboard = new QRadioButton(buttonGroup2);
        checkClipboard->setObjectName(QString::fromUtf8("checkClipboard"));

        vboxLayout1->addWidget(checkClipboard);

        checkServer = new QRadioButton(buttonGroup2);
        checkServer->setObjectName(QString::fromUtf8("checkServer"));
        checkServer->setEnabled(false);

        vboxLayout1->addWidget(checkServer);

        destServer = new KComboBox(buttonGroup2);
        destServer->setObjectName(QString::fromUtf8("destServer"));
        destServer->setEnabled(false);

        vboxLayout1->addWidget(destServer);

        checkFile = new QRadioButton(buttonGroup2);
        checkFile->setObjectName(QString::fromUtf8("checkFile"));
        checkFile->setChecked(true);

        vboxLayout1->addWidget(checkFile);

        newFilename = new KUrlRequester(buttonGroup2);
        newFilename->setObjectName(QString::fromUtf8("newFilename"));
        newFilename->setEnabled(true);

        vboxLayout1->addWidget(newFilename);


        verticalLayout->addWidget(buttonGroup2);

        buttonGroup3 = new QGroupBox(widget);
        buttonGroup3->setObjectName(QString::fromUtf8("buttonGroup3"));
        vboxLayout2 = new QVBoxLayout(buttonGroup3);
        vboxLayout2->setObjectName(QString::fromUtf8("vboxLayout2"));
        checkAttrAll = new QRadioButton(buttonGroup3);
        checkAttrAll->setObjectName(QString::fromUtf8("checkAttrAll"));
        checkAttrAll->setChecked(true);

        vboxLayout2->addWidget(checkAttrAll);

        checkAttrPhoto = new QRadioButton(buttonGroup3);
        checkAttrPhoto->setObjectName(QString::fromUtf8("checkAttrPhoto"));

        vboxLayout2->addWidget(checkAttrPhoto);

        checkAttrClean = new QRadioButton(buttonGroup3);
        checkAttrClean->setObjectName(QString::fromUtf8("checkAttrClean"));

        vboxLayout2->addWidget(checkAttrClean);

        spacerItem = new QSpacerItem(602, 108, QSizePolicy::Minimum, QSizePolicy::Minimum);

        vboxLayout2->addItem(spacerItem);


        verticalLayout->addWidget(buttonGroup3);


        vboxLayout->addWidget(widget);


        retranslateUi(KeyExport);
        QObject::connect(checkServer, SIGNAL(toggled(bool)), destServer, SLOT(setEnabled(bool)));
        QObject::connect(checkFile, SIGNAL(toggled(bool)), newFilename, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(KeyExport);
    } // setupUi

    void retranslateUi(QWidget *KeyExport)
    {
        buttonGroup2->setTitle(QString());
        checkMail->setText(tr2i18n("Email", "Export a key via email"));
        checkClipboard->setText(tr2i18n("Clipboard", 0));
#ifndef UI_QT_NO_TOOLTIP
        checkServer->setToolTip(tr2i18n("You must define at least one keyserver in settings before you can export to one.", 0));
#endif // QT_NO_TOOLTIP
        checkServer->setText(tr2i18n("Key server:", 0));
        checkFile->setText(tr2i18n("File:", 0));
        buttonGroup3->setTitle(tr2i18n("Export Settings", 0));
        checkAttrAll->setText(tr2i18n("Export everything", 0));
        checkAttrPhoto->setText(tr2i18n("Do not export attributes (photo ids)", 0));
        checkAttrClean->setText(tr2i18n("Clean key", "@option:radio Exports the smallest key possible. Maps to export-minimal option of gpg"));
        Q_UNUSED(KeyExport);
    } // retranslateUi

};

namespace Ui {
    class KeyExport: public Ui_KeyExport {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KEYEXPORT_H

