#include <kdialog.h>
#include <klocale.h>

/********************************************************************************
** Form generated from reading UI file 'keyserver.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KEYSERVER_H
#define UI_KEYSERVER_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QCheckBox>
#include <QtGui/QGridLayout>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QPushButton>
#include <QtGui/QSpacerItem>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include "kcombobox.h"
#include "klineedit.h"
#include "ktabwidget.h"

QT_BEGIN_NAMESPACE

class Ui_keyServerWidget
{
public:
    QGridLayout *gridLayout;
    KTabWidget *tabWidget2;
    QWidget *tab_import;
    QVBoxLayout *vboxLayout;
    QLabel *textLabel1;
    KComboBox *kCBimportks;
    QLabel *textLabel2;
    KLineEdit *kLEimportid;
    QHBoxLayout *hboxLayout;
    QCheckBox *cBproxyI;
    KLineEdit *kLEproxyI;
    QSpacerItem *spacerItem;
    QHBoxLayout *hboxLayout1;
    QPushButton *Buttonsearch;
    QPushButton *Buttonimport;
    QSpacerItem *spacerItem1;
    QWidget *tab_export;
    QVBoxLayout *vboxLayout1;
    QLabel *textLabel3;
    KComboBox *kCBexportks;
    QLabel *textLabel4;
    KComboBox *kCBexportkey;
    QCheckBox *exportAttributes;
    QHBoxLayout *hboxLayout2;
    QCheckBox *cBproxyE;
    KLineEdit *kLEproxyE;
    QSpacerItem *spacerItem2;
    QHBoxLayout *hboxLayout3;
    QPushButton *Buttonexport;
    QSpacerItem *spacerItem3;

    void setupUi(QWidget *keyServerWidget)
    {
        if (keyServerWidget->objectName().isEmpty())
            keyServerWidget->setObjectName(QString::fromUtf8("keyServerWidget"));
        keyServerWidget->resize(529, 339);
        gridLayout = new QGridLayout(keyServerWidget);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        tabWidget2 = new KTabWidget(keyServerWidget);
        tabWidget2->setObjectName(QString::fromUtf8("tabWidget2"));
        tab_import = new QWidget();
        tab_import->setObjectName(QString::fromUtf8("tab_import"));
        vboxLayout = new QVBoxLayout(tab_import);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        textLabel1 = new QLabel(tab_import);
        textLabel1->setObjectName(QString::fromUtf8("textLabel1"));
        textLabel1->setWordWrap(false);

        vboxLayout->addWidget(textLabel1);

        kCBimportks = new KComboBox(tab_import);
        kCBimportks->setObjectName(QString::fromUtf8("kCBimportks"));

        vboxLayout->addWidget(kCBimportks);

        textLabel2 = new QLabel(tab_import);
        textLabel2->setObjectName(QString::fromUtf8("textLabel2"));
        textLabel2->setFrameShape(QFrame::NoFrame);
        textLabel2->setFrameShadow(QFrame::Plain);
        textLabel2->setWordWrap(false);

        vboxLayout->addWidget(textLabel2);

        kLEimportid = new KLineEdit(tab_import);
        kLEimportid->setObjectName(QString::fromUtf8("kLEimportid"));
        kLEimportid->setClearButtonShown(true);

        vboxLayout->addWidget(kLEimportid);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        cBproxyI = new QCheckBox(tab_import);
        cBproxyI->setObjectName(QString::fromUtf8("cBproxyI"));
        cBproxyI->setEnabled(false);

        hboxLayout->addWidget(cBproxyI);

        kLEproxyI = new KLineEdit(tab_import);
        kLEproxyI->setObjectName(QString::fromUtf8("kLEproxyI"));
        kLEproxyI->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kLEproxyI->sizePolicy().hasHeightForWidth());
        kLEproxyI->setSizePolicy(sizePolicy);
        kLEproxyI->setReadOnly(true);

        hboxLayout->addWidget(kLEproxyI);


        vboxLayout->addLayout(hboxLayout);

        spacerItem = new QSpacerItem(477, 121, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);

        vboxLayout->addItem(spacerItem);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName(QString::fromUtf8("hboxLayout1"));
        Buttonsearch = new QPushButton(tab_import);
        Buttonsearch->setObjectName(QString::fromUtf8("Buttonsearch"));
        Buttonsearch->setDefault(true);

        hboxLayout1->addWidget(Buttonsearch);

        Buttonimport = new QPushButton(tab_import);
        Buttonimport->setObjectName(QString::fromUtf8("Buttonimport"));

        hboxLayout1->addWidget(Buttonimport);

        spacerItem1 = new QSpacerItem(160, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacerItem1);


        vboxLayout->addLayout(hboxLayout1);

        tabWidget2->addTab(tab_import, QString());
        tab_export = new QWidget();
        tab_export->setObjectName(QString::fromUtf8("tab_export"));
        vboxLayout1 = new QVBoxLayout(tab_export);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        textLabel3 = new QLabel(tab_export);
        textLabel3->setObjectName(QString::fromUtf8("textLabel3"));
        textLabel3->setWordWrap(false);

        vboxLayout1->addWidget(textLabel3);

        kCBexportks = new KComboBox(tab_export);
        kCBexportks->setObjectName(QString::fromUtf8("kCBexportks"));

        vboxLayout1->addWidget(kCBexportks);

        textLabel4 = new QLabel(tab_export);
        textLabel4->setObjectName(QString::fromUtf8("textLabel4"));
        textLabel4->setWordWrap(false);

        vboxLayout1->addWidget(textLabel4);

        kCBexportkey = new KComboBox(tab_export);
        kCBexportkey->setObjectName(QString::fromUtf8("kCBexportkey"));

        vboxLayout1->addWidget(kCBexportkey);

        exportAttributes = new QCheckBox(tab_export);
        exportAttributes->setObjectName(QString::fromUtf8("exportAttributes"));
        exportAttributes->setChecked(true);

        vboxLayout1->addWidget(exportAttributes);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName(QString::fromUtf8("hboxLayout2"));
        cBproxyE = new QCheckBox(tab_export);
        cBproxyE->setObjectName(QString::fromUtf8("cBproxyE"));
        cBproxyE->setEnabled(false);

        hboxLayout2->addWidget(cBproxyE);

        kLEproxyE = new KLineEdit(tab_export);
        kLEproxyE->setObjectName(QString::fromUtf8("kLEproxyE"));
        kLEproxyE->setEnabled(false);
        sizePolicy.setHeightForWidth(kLEproxyE->sizePolicy().hasHeightForWidth());
        kLEproxyE->setSizePolicy(sizePolicy);
        kLEproxyE->setReadOnly(true);

        hboxLayout2->addWidget(kLEproxyE);


        vboxLayout1->addLayout(hboxLayout2);

        spacerItem2 = new QSpacerItem(507, 63, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);

        vboxLayout1->addItem(spacerItem2);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setObjectName(QString::fromUtf8("hboxLayout3"));
        Buttonexport = new QPushButton(tab_export);
        Buttonexport->setObjectName(QString::fromUtf8("Buttonexport"));

        hboxLayout3->addWidget(Buttonexport);

        spacerItem3 = new QSpacerItem(250, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout3->addItem(spacerItem3);


        vboxLayout1->addLayout(hboxLayout3);

        tabWidget2->addTab(tab_export, QString());

        gridLayout->addWidget(tabWidget2, 0, 0, 1, 1);


        retranslateUi(keyServerWidget);

        tabWidget2->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(keyServerWidget);
    } // setupUi

    void retranslateUi(QWidget *keyServerWidget)
    {
#ifndef UI_QT_NO_WHATSTHIS
        textLabel1->setWhatsThis(tr2i18n("<qt><b>Key Server:</b><br /> <p>A Key Server is a centralized repository of PGP/GnuPG keys connected to the Internet which can be conveniently accessed in order to obtain or deposit keys. Select from the drop down list to specify which key server should be used.</p> <p>Often these keys are held by people whom the user has never met and as such the authenticity is dubious at best. Refer to the GnuPG manual covering \"Web-of-Trust\" relationships to find out how GnuPG works around the problem of verifying authenticity.</p> </qt>", 0));
#endif // QT_NO_WHATSTHIS
        textLabel1->setText(tr2i18n("Key server:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        kCBimportks->setWhatsThis(tr2i18n("<b>Key Server Drop Down Dialog:</b>\n"
"Allows the user to select the Key Server which will be used to import PGP/GnuPG keys into the local keyring.", 0));
#endif // QT_NO_WHATSTHIS
#ifndef UI_QT_NO_WHATSTHIS
        textLabel2->setWhatsThis(tr2i18n("<qt><b>Text to search or ID of the key to import:</b><br />\n"
"<p>There are multiple ways to search for a key, you can use a text or partial text search (example: entering Phil or Zimmerman will bring up all keys in which Phil or Zimmerman shows up) or you can search by the ID's of the key. Key ID's are strings of letters and numbers that uniquely identify a key (example: searching for 0xED7585F4 would bring up the key associated with that ID).</p></qt>", 0));
#endif // QT_NO_WHATSTHIS
        textLabel2->setText(tr2i18n("Text to search or ID of the key to import:", 0));
        cBproxyI->setText(tr2i18n("Honor HTTP proxy:", 0));
        Buttonsearch->setText(tr2i18n("&Search", 0));
        Buttonimport->setText(tr2i18n("&Import", 0));
        tabWidget2->setTabText(tabWidget2->indexOf(tab_import), tr2i18n("Import", 0));
        textLabel3->setText(tr2i18n("Key server:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        textLabel4->setWhatsThis(tr2i18n("<qt><b>Key to be exported:</b><br />\n"
"<p>This allows the user to specify the key from the drop down list that will be exported to the key server selected.</p></qt>", 0));
#endif // QT_NO_WHATSTHIS
        textLabel4->setText(tr2i18n("Key to be exported:", 0));
        exportAttributes->setText(tr2i18n("Export attributes (photo id)", 0));
        cBproxyE->setText(tr2i18n("Honor HTTP proxy:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        Buttonexport->setWhatsThis(tr2i18n("<qt><b>Export:</b><br />\n"
"<p>Pushing this button will export the specified key to the specified server.</p></qt>", 0));
#endif // QT_NO_WHATSTHIS
        Buttonexport->setText(tr2i18n("&Export", 0));
        tabWidget2->setTabText(tabWidget2->indexOf(tab_export), tr2i18n("Export", 0));
        Q_UNUSED(keyServerWidget);
    } // retranslateUi

};

namespace Ui {
    class keyServerWidget: public Ui_keyServerWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KEYSERVER_H

