/*
 * This file was generated by qdbusxml2cpp version 0.7
 * Command line was: qdbusxml2cpp -m -a keyadaptor -i keysmanager.h -l KeysManager /usr/src/ports/kgpg/kgpg-16.08.3-1.x86_64/src/kgpg-16.08.3/org.kde.kgpg.Key.xml
 *
 * qdbusxml2cpp is Copyright (C) 2015 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "keyadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KeyAdaptor
 */

KeyAdaptor::KeyAdaptor(KeysManager *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KeyAdaptor::~KeyAdaptor()
{
    // destructor
}

bool KeyAdaptor::importRemoteKey(const QString &keyID)
{
    // handle method call org.kde.kgpg.Key.importRemoteKey
    return parent()->importRemoteKey(keyID);
}

void KeyAdaptor::showKeyInfo(const QString &keyID)
{
    // handle method call org.kde.kgpg.Key.showKeyInfo
    parent()->showKeyInfo(keyID);
}

void KeyAdaptor::showKeyManager()
{
    // handle method call org.kde.kgpg.Key.showKeyManager
    parent()->showKeyManager();
}

void KeyAdaptor::showKeyServer()
{
    // handle method call org.kde.kgpg.Key.showKeyServer
    parent()->showKeyServer();
}

void KeyAdaptor::showOptions()
{
    // handle method call org.kde.kgpg.Key.showOptions
    parent()->showOptions();
}


#include "keyadaptor.moc"
