/****************************************************************************
** Meta object code from reading C++ file 'kgpgoptions.h'
**
** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kgpg-16.08.3/kgpgoptions.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgpgoptions.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 63
#error "This file was generated using the moc from 4.8.7. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_kgpgOptions[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
      21,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: signature, parameters, type, tag, flags
      13,   12,   12,   12, 0x05,
      29,   12,   12,   12, 0x05,
      47,   12,   12,   12, 0x05,
      65,   12,   12,   12, 0x05,
      81,   79,   12,   12, 0x05,

 // slots: signature, parameters, type, tag, flags
     125,   12,   12,   12, 0x08,
     142,   12,   12,   12, 0x08,
     161,   12,   12,   12, 0x08,
     183,   12,   12,   12, 0x08,
     202,   12,   12,   12, 0x08,
     228,  222,   12,   12, 0x08,
     259,   12,   12,   12, 0x08,
     293,   12,   12,   12, 0x08,
     316,   12,   12,   12, 0x08,
     332,   12,   12,   12, 0x08,
     355,   12,   12,   12, 0x08,
     372,   12,   12,   12, 0x08,
     392,  383,   12,   12, 0x08,
     420,  383,   12,   12, 0x08,
     450,  445,   12,   12, 0x08,
     474,   12,   12,   12, 0x08,

       0        // eod
};

static const char qt_meta_stringdata_kgpgOptions[] = {
    "kgpgOptions\0\0updateDisplay()\0"
    "settingsUpdated()\0changeFont(QFont)\0"
    "homeChanged()\0,\0"
    "refreshTrust(KgpgCore::KgpgKeyTrust,QColor)\0"
    "slotChangeHome()\0slotAddKeyServer()\0"
    "slotChangeEncryptTo()\0slotDelKeyServer()\0"
    "slotEditKeyServer()\0index\0"
    "slotEditKeyServer(QModelIndex)\0"
    "slotChangeKeyServerButtonEnable()\0"
    "slotDefaultKeyServer()\0updateWidgets()\0"
    "updateWidgetsDefault()\0updateSettings()\0"
    "listKeys()\0mimetype\0slotInstallDecrypt(QString)\0"
    "slotInstallSign(QString)\0menu\0"
    "slotRemoveMenu(QString)\0slotSystrayEnable()\0"
};

void kgpgOptions::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Q_ASSERT(staticMetaObject.cast(_o));
        kgpgOptions *_t = static_cast<kgpgOptions *>(_o);
        switch (_id) {
        case 0: _t->updateDisplay(); break;
        case 1: _t->settingsUpdated(); break;
        case 2: _t->changeFont((*reinterpret_cast< QFont(*)>(_a[1]))); break;
        case 3: _t->homeChanged(); break;
        case 4: _t->refreshTrust((*reinterpret_cast< KgpgCore::KgpgKeyTrust(*)>(_a[1])),(*reinterpret_cast< QColor(*)>(_a[2]))); break;
        case 5: _t->slotChangeHome(); break;
        case 6: _t->slotAddKeyServer(); break;
        case 7: _t->slotChangeEncryptTo(); break;
        case 8: _t->slotDelKeyServer(); break;
        case 9: _t->slotEditKeyServer(); break;
        case 10: _t->slotEditKeyServer((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 11: _t->slotChangeKeyServerButtonEnable(); break;
        case 12: _t->slotDefaultKeyServer(); break;
        case 13: _t->updateWidgets(); break;
        case 14: _t->updateWidgetsDefault(); break;
        case 15: _t->updateSettings(); break;
        case 16: _t->listKeys(); break;
        case 17: _t->slotInstallDecrypt((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 18: _t->slotInstallSign((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 19: _t->slotRemoveMenu((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 20: _t->slotSystrayEnable(); break;
        default: ;
        }
    }
}

const QMetaObjectExtraData kgpgOptions::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject kgpgOptions::staticMetaObject = {
    { &KConfigDialog::staticMetaObject, qt_meta_stringdata_kgpgOptions,
      qt_meta_data_kgpgOptions, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &kgpgOptions::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *kgpgOptions::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *kgpgOptions::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_kgpgOptions))
        return static_cast<void*>(const_cast< kgpgOptions*>(this));
    return KConfigDialog::qt_metacast(_clname);
}

int kgpgOptions::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void kgpgOptions::updateDisplay()
{
    QMetaObject::activate(this, &staticMetaObject, 0, 0);
}

// SIGNAL 1
void kgpgOptions::settingsUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, 0);
}

// SIGNAL 2
void kgpgOptions::changeFont(QFont _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void kgpgOptions::homeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, 0);
}

// SIGNAL 4
void kgpgOptions::refreshTrust(KgpgCore::KgpgKeyTrust _t1, QColor _t2)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_END_MOC_NAMESPACE
