/****************************************************************************
** Meta object code from reading C++ file 'kgpgitemmodel.h'
**
** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kgpg-16.08.3/model/kgpgitemmodel.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgpgitemmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 63
#error "This file was generated using the moc from 4.8.7. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_KGpgItemModel[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: signature, parameters, type, tag, flags
      40,   30,   15,   14, 0x0a,
      81,   76,   14,   14, 0x0a,
     110,  100,   14,   14, 0x0a,
     166,  153,   14,   14, 0x0a,
     223,  219,   14,   14, 0x0a,
     275,  263,  251,   14, 0x0a,
     300,   76,  251,   14, 0x2a,
     324,  321,   14,   14, 0x0a,
     347,  344,   14,   14, 0x0a,
     376,  372,   14,   14, 0x0a,
     401,   14,   14,   14, 0x2a,
     420,  415,   14,   14, 0x0a,
     451,   14,   14,   14, 0x0a,
     467,  344,   14,   14, 0x0a,
     508,  496,   14,   14, 0x0a,

       0        // eod
};

static const char qt_meta_stringdata_KGpgItemModel[] = {
    "KGpgItemModel\0\0KGpgGroupNode*\0name,keys\0"
    "addGroup(QString,KGpgKeyNode::List)\0"
    "node\0delNode(KGpgNode*)\0node,keys\0"
    "changeGroup(KGpgGroupNode*,KGpgNode::List)\0"
    "group,member\0"
    "deleteFromGroup(KGpgGroupNode*,KGpgGroupMemberNode*)\0"
    "def\0setDefaultKey(KGpgKeyNode*)\0"
    "QModelIndex\0node,column\0"
    "nodeIndex(KGpgNode*,int)\0nodeIndex(KGpgNode*)\0"
    "id\0refreshKey(QString)\0nd\0"
    "refreshKey(KGpgKeyNode*)\0ids\0"
    "refreshKeys(QStringList)\0refreshKeys()\0"
    "keys\0refreshKeys(KGpgKeyNode::List)\0"
    "refreshGroups()\0invalidateIndexes(KGpgNode*)\0"
    "trust,color\0refreshTrust(KgpgCore::KgpgKeyTrust,QColor)\0"
};

void KGpgItemModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Q_ASSERT(staticMetaObject.cast(_o));
        KGpgItemModel *_t = static_cast<KGpgItemModel *>(_o);
        switch (_id) {
        case 0: { KGpgGroupNode* _r = _t->addGroup((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const KGpgKeyNode::List(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< KGpgGroupNode**>(_a[0]) = _r; }  break;
        case 1: _t->delNode((*reinterpret_cast< KGpgNode*(*)>(_a[1]))); break;
        case 2: _t->changeGroup((*reinterpret_cast< KGpgGroupNode*(*)>(_a[1])),(*reinterpret_cast< const KGpgNode::List(*)>(_a[2]))); break;
        case 3: _t->deleteFromGroup((*reinterpret_cast< KGpgGroupNode*(*)>(_a[1])),(*reinterpret_cast< KGpgGroupMemberNode*(*)>(_a[2]))); break;
        case 4: _t->setDefaultKey((*reinterpret_cast< KGpgKeyNode*(*)>(_a[1]))); break;
        case 5: { QModelIndex _r = _t->nodeIndex((*reinterpret_cast< KGpgNode*(*)>(_a[1])),(*reinterpret_cast< const int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QModelIndex*>(_a[0]) = _r; }  break;
        case 6: { QModelIndex _r = _t->nodeIndex((*reinterpret_cast< KGpgNode*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QModelIndex*>(_a[0]) = _r; }  break;
        case 7: _t->refreshKey((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->refreshKey((*reinterpret_cast< KGpgKeyNode*(*)>(_a[1]))); break;
        case 9: _t->refreshKeys((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 10: _t->refreshKeys(); break;
        case 11: _t->refreshKeys((*reinterpret_cast< KGpgKeyNode::List(*)>(_a[1]))); break;
        case 12: _t->refreshGroups(); break;
        case 13: _t->invalidateIndexes((*reinterpret_cast< KGpgNode*(*)>(_a[1]))); break;
        case 14: _t->refreshTrust((*reinterpret_cast< const KgpgCore::KgpgKeyTrust(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObjectExtraData KGpgItemModel::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject KGpgItemModel::staticMetaObject = {
    { &QAbstractItemModel::staticMetaObject, qt_meta_stringdata_KGpgItemModel,
      qt_meta_data_KGpgItemModel, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &KGpgItemModel::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *KGpgItemModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *KGpgItemModel::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_KGpgItemModel))
        return static_cast<void*>(const_cast< KGpgItemModel*>(this));
    return QAbstractItemModel::qt_metacast(_clname);
}

int KGpgItemModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
