#include <kdialog.h>
#include <klocale.h>

/********************************************************************************
** Form generated from reading UI file 'kgpgkeygenerate.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KGPGKEYGENERATE_H
#define UI_KGPGKEYGENERATE_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QCheckBox>
#include <QtGui/QFormLayout>
#include <QtGui/QGroupBox>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QVBoxLayout>
#include "kcombobox.h"
#include "kdialog.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_kgpgKeyGenerate
{
public:
    QGroupBox *vgroup;
    QVBoxLayout *verticalLayout;
    QLabel *nameLabel;
    KLineEdit *m_kname;
    QLabel *emailLabel;
    KLineEdit *m_mail;
    QLabel *label_2;
    KLineEdit *m_comment;
    QLabel *label_3;
    KLineEdit *m_days;
    QLabel *label_4;
    KComboBox *m_keysize;
    QLabel *label_5;
    KComboBox *m_keykind;
    QGroupBox *capabilities;
    QFormLayout *formLayout;
    QCheckBox *capCert;
    QCheckBox *capSign;
    QCheckBox *capAuth;
    QCheckBox *capEncrypt;

    void setupUi(KDialog *kgpgKeyGenerate)
    {
        if (kgpgKeyGenerate->objectName().isEmpty())
            kgpgKeyGenerate->setObjectName(QString::fromUtf8("kgpgKeyGenerate"));
        kgpgKeyGenerate->resize(367, 464);
        vgroup = new QGroupBox(kgpgKeyGenerate);
        vgroup->setObjectName(QString::fromUtf8("vgroup"));
        vgroup->setGeometry(QRect(0, 10, 361, 434));
        verticalLayout = new QVBoxLayout(vgroup);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        nameLabel = new QLabel(vgroup);
        nameLabel->setObjectName(QString::fromUtf8("nameLabel"));

        verticalLayout->addWidget(nameLabel);

        m_kname = new KLineEdit(vgroup);
        m_kname->setObjectName(QString::fromUtf8("m_kname"));

        verticalLayout->addWidget(m_kname);

        emailLabel = new QLabel(vgroup);
        emailLabel->setObjectName(QString::fromUtf8("emailLabel"));

        verticalLayout->addWidget(emailLabel);

        m_mail = new KLineEdit(vgroup);
        m_mail->setObjectName(QString::fromUtf8("m_mail"));

        verticalLayout->addWidget(m_mail);

        label_2 = new QLabel(vgroup);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        verticalLayout->addWidget(label_2);

        m_comment = new KLineEdit(vgroup);
        m_comment->setObjectName(QString::fromUtf8("m_comment"));

        verticalLayout->addWidget(m_comment);

        label_3 = new QLabel(vgroup);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        verticalLayout->addWidget(label_3);

        m_days = new KLineEdit(vgroup);
        m_days->setObjectName(QString::fromUtf8("m_days"));

        verticalLayout->addWidget(m_days);

        label_4 = new QLabel(vgroup);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        verticalLayout->addWidget(label_4);

        m_keysize = new KComboBox(vgroup);
        m_keysize->setObjectName(QString::fromUtf8("m_keysize"));

        verticalLayout->addWidget(m_keysize);

        label_5 = new QLabel(vgroup);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        verticalLayout->addWidget(label_5);

        m_keykind = new KComboBox(vgroup);
        m_keykind->setObjectName(QString::fromUtf8("m_keykind"));

        verticalLayout->addWidget(m_keykind);

        capabilities = new QGroupBox(vgroup);
        capabilities->setObjectName(QString::fromUtf8("capabilities"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(capabilities->sizePolicy().hasHeightForWidth());
        capabilities->setSizePolicy(sizePolicy);
        formLayout = new QFormLayout(capabilities);
        formLayout->setObjectName(QString::fromUtf8("formLayout"));
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        capCert = new QCheckBox(capabilities);
        capCert->setObjectName(QString::fromUtf8("capCert"));
        capCert->setEnabled(false);
        capCert->setChecked(true);

        formLayout->setWidget(0, QFormLayout::FieldRole, capCert);

        capSign = new QCheckBox(capabilities);
        capSign->setObjectName(QString::fromUtf8("capSign"));
        capSign->setChecked(true);

        formLayout->setWidget(3, QFormLayout::FieldRole, capSign);

        capAuth = new QCheckBox(capabilities);
        capAuth->setObjectName(QString::fromUtf8("capAuth"));
        capAuth->setChecked(true);

        formLayout->setWidget(1, QFormLayout::FieldRole, capAuth);

        capEncrypt = new QCheckBox(capabilities);
        capEncrypt->setObjectName(QString::fromUtf8("capEncrypt"));
        capEncrypt->setChecked(true);

        formLayout->setWidget(2, QFormLayout::FieldRole, capEncrypt);


        verticalLayout->addWidget(capabilities);

#ifndef UI_QT_NO_SHORTCUT
        nameLabel->setBuddy(m_kname);
        emailLabel->setBuddy(m_mail);
        label_2->setBuddy(m_comment);
        label_3->setBuddy(m_days);
        label_4->setBuddy(m_keysize);
        label_5->setBuddy(m_keykind);
#endif // QT_NO_SHORTCUT

        retranslateUi(kgpgKeyGenerate);

        QMetaObject::connectSlotsByName(kgpgKeyGenerate);
    } // setupUi

    void retranslateUi(KDialog *kgpgKeyGenerate)
    {
        kgpgKeyGenerate->setWindowTitle(tr2i18n("Key Generation", 0));
        vgroup->setTitle(tr2i18n("Generate Key Pair", 0));
        nameLabel->setText(tr2i18n("&Name:", 0));
#ifndef UI_QT_NO_TOOLTIP
        m_kname->setToolTip(tr2i18n("The name must have a length of at least 5 characters and must not begin with a digit.", 0));
#endif // QT_NO_TOOLTIP
        m_kname->setPlaceholderText(tr2i18n("Real name, at least 5 characters, no leading digits", 0));
        emailLabel->setText(tr2i18n("E&mail (optional):", 0));
        label_2->setText(tr2i18n("Commen&t (optional):", 0));
        label_3->setText(tr2i18n("Expiration:", 0));
        m_days->setText(tr2i18n("0", 0));
        label_4->setText(tr2i18n("&Key size:", 0));
        label_5->setText(tr2i18n("&Algorithm:", 0));
        capabilities->setTitle(tr2i18n("Capabilities", 0));
#ifndef UI_QT_NO_TOOLTIP
        capCert->setToolTip(tr2i18n("Certification is automatically enabled for all keys", 0));
#endif // QT_NO_TOOLTIP
        capCert->setText(tr2i18n("Certification", 0));
        capSign->setText(tr2i18n("Signature", 0));
        capAuth->setText(tr2i18n("Authentication", 0));
        capEncrypt->setText(tr2i18n("Encryption", 0));
    } // retranslateUi

};

namespace Ui {
    class kgpgKeyGenerate: public Ui_kgpgKeyGenerate {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KGPGKEYGENERATE_H

