/****************************************************************************
** Meta object code from reading C++ file 'keyinfodialog.h'
**
** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kgpg-16.08.3/keyinfodialog.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keyinfodialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 63
#error "This file was generated using the moc from 4.8.7. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_KgpgTrustLabel[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

static const char qt_meta_stringdata_KgpgTrustLabel[] = {
    "KgpgTrustLabel\0"
};

void KgpgTrustLabel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObjectExtraData KgpgTrustLabel::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject KgpgTrustLabel::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KgpgTrustLabel,
      qt_meta_data_KgpgTrustLabel, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &KgpgTrustLabel::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *KgpgTrustLabel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *KgpgTrustLabel::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_KgpgTrustLabel))
        return static_cast<void*>(const_cast< KgpgTrustLabel*>(this));
    return QWidget::qt_metacast(_clname);
}

int KgpgTrustLabel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
static const uint qt_meta_data_KgpgKeyInfo[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: signature, parameters, type, tag, flags
      18,   13,   12,   12, 0x05,

 // slots: signature, parameters, type, tag, flags
      55,   48,   12,   12, 0x09,
      82,   78,   12,   12, 0x08,
     103,   12,   12,   12, 0x08,
     125,  120,   12,   12, 0x08,
     146,   12,   12,   12, 0x08,
     170,  163,   12,   12, 0x08,
     208,  199,   12,   12, 0x08,
     233,  229,   12,   12, 0x08,
     256,  163,   12,   12, 0x08,
     273,   12,   12,   12, 0x08,

       0        // eod
};

static const char qt_meta_stringdata_KgpgKeyInfo[] = {
    "KgpgKeyInfo\0\0node\0keyNeedsRefresh(KGpgKeyNode*)\0"
    "button\0slotButtonClicked(int)\0url\0"
    "slotOpenUrl(QString)\0slotChangeDate()\0"
    "ison\0slotDisableKey(bool)\0slotChangePass()\0"
    "result\0slotInfoPasswordChanged(int)\0"
    "newtrust\0slotChangeTrust(int)\0uid\0"
    "slotLoadPhoto(QString)\0slotApplied(int)\0"
    "slotKeyExpanded()\0"
};

void KgpgKeyInfo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Q_ASSERT(staticMetaObject.cast(_o));
        KgpgKeyInfo *_t = static_cast<KgpgKeyInfo *>(_o);
        switch (_id) {
        case 0: _t->keyNeedsRefresh((*reinterpret_cast< KGpgKeyNode*(*)>(_a[1]))); break;
        case 1: _t->slotButtonClicked((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->slotOpenUrl((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->slotChangeDate(); break;
        case 4: _t->slotDisableKey((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 5: _t->slotChangePass(); break;
        case 6: _t->slotInfoPasswordChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->slotChangeTrust((*reinterpret_cast< const int(*)>(_a[1]))); break;
        case 8: _t->slotLoadPhoto((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->slotApplied((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->slotKeyExpanded(); break;
        default: ;
        }
    }
}

const QMetaObjectExtraData KgpgKeyInfo::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject KgpgKeyInfo::staticMetaObject = {
    { &KDialog::staticMetaObject, qt_meta_stringdata_KgpgKeyInfo,
      qt_meta_data_KgpgKeyInfo, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &KgpgKeyInfo::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *KgpgKeyInfo::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *KgpgKeyInfo::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_KgpgKeyInfo))
        return static_cast<void*>(const_cast< KgpgKeyInfo*>(this));
    if (!strcmp(_clname, "Ui::kgpgKeyInfo"))
        return static_cast< Ui::kgpgKeyInfo*>(const_cast< KgpgKeyInfo*>(this));
    return KDialog::qt_metacast(_clname);
}

int KgpgKeyInfo::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void KgpgKeyInfo::keyNeedsRefresh(KGpgKeyNode * _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_END_MOC_NAMESPACE
