/****************************************************************************
** Meta object code from reading C++ file 'kgpgeditor.h'
**
** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kgpg-16.08.3/editor/kgpgeditor.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgpgeditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 63
#error "This file was generated using the moc from 4.8.7. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_KgpgEditor[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
      43,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: signature, parameters, type, tag, flags
      12,   11,   11,   11, 0x05,
      29,   11,   11,   11, 0x05,

 // slots: signature, parameters, type, tag, flags
      61,   48,   11,   11, 0x0a,
      96,   92,   11,   11, 0x2a,
     126,  119,   11,   11, 0x0a,
     145,   11,   11,   11, 0x0a,
     159,   11,   11,   11, 0x08,
     173,   11,   11,   11, 0x08,
     193,   11,  188,   11, 0x08,
     208,   11,  188,   11, 0x08,
     225,   11,   11,   11, 0x08,
     241,   11,   11,   11, 0x08,
     258,   11,   11,   11, 0x08,
     275,   11,   11,   11, 0x08,
     292,   11,   11,   11, 0x08,
     308,   11,   11,   11, 0x08,
     319,   11,   11,   11, 0x08,
     330,   11,   11,   11, 0x08,
     344,   11,   11,   11, 0x08,
     359,   11,   11,   11, 0x08,
     375,   11,   11,   11, 0x08,
     391,   11,   11,   11, 0x08,
     402,   11,   11,   11, 0x08,
     417,   11,   11,   11, 0x08,
     432,   11,   11,   11, 0x08,
     447,   11,   11,   11, 0x08,
     468,  464,   11,   11, 0x08,
     498,  492,  188,   11, 0x08,
     525,   11,   11,   11, 0x08,
     543,   92,   11,   11, 0x08,
     562,   11,   11,   11, 0x08,
     580,   11,   11,   11, 0x08,
     600,   92,   11,   11, 0x08,
     621,   11,   11,   11, 0x08,
     648,  636,   11,   11, 0x08,
     684,   11,   11,   11, 0x08,
     700,  698,   11,   11, 0x08,
     724,  698,   11,   11, 0x08,
     748,  698,   11,   11, 0x08,
     772,   11,   11,   11, 0x08,
     783,   11,   11,   11, 0x08,
     793,   11,   11,   11, 0x08,
     815,  811,   11,   11, 0x08,

       0        // eod
};

static const char qt_meta_stringdata_KgpgEditor[] = {
    "KgpgEditor\0\0openChangeFont()\0"
    "openConfigDialog()\0url,encoding\0"
    "openDocumentFile(KUrl,QString)\0url\0"
    "openDocumentFile(KUrl)\0myFont\0"
    "slotSetFont(QFont)\0closeWindow()\0"
    "slotFileNew()\0slotFileOpen()\0bool\0"
    "slotFileSave()\0slotFileSaveAs()\0"
    "slotFilePrint()\0slotFilePreEnc()\0"
    "slotFilePreDec()\0slotKeyManager()\0"
    "slotFileClose()\0slotundo()\0slotredo()\0"
    "slotEditCut()\0slotEditCopy()\0"
    "slotEditPaste()\0slotSelectAll()\0"
    "slotFind()\0slotFindNext()\0slotFindPrev()\0"
    "slotFindText()\0slotSetCharset()\0enc\0"
    "slotResetEncoding(bool)\0codec\0"
    "checkEncoding(QTextCodec*)\0slotPreSignFile()\0"
    "slotSignFile(KUrl)\0slotSignFileFin()\0"
    "slotPreVerifyFile()\0slotVerifyFile(KUrl)\0"
    "slotCheckMd5()\0id,fileName\0"
    "importSignatureKey(QString,QString)\0"
    "slotOptions()\0v\0slotUndoAvailable(bool)\0"
    "slotRedoAvailable(bool)\0slotCopyAvailable(bool)\0"
    "modified()\0newText()\0slotLibraryDone()\0"
    "ids\0slotDownloadKeysFinished(QStringList)\0"
};

void KgpgEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Q_ASSERT(staticMetaObject.cast(_o));
        KgpgEditor *_t = static_cast<KgpgEditor *>(_o);
        switch (_id) {
        case 0: _t->openChangeFont(); break;
        case 1: _t->openConfigDialog(); break;
        case 2: _t->openDocumentFile((*reinterpret_cast< const KUrl(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 3: _t->openDocumentFile((*reinterpret_cast< const KUrl(*)>(_a[1]))); break;
        case 4: _t->slotSetFont((*reinterpret_cast< QFont(*)>(_a[1]))); break;
        case 5: _t->closeWindow(); break;
        case 6: _t->slotFileNew(); break;
        case 7: _t->slotFileOpen(); break;
        case 8: { bool _r = _t->slotFileSave();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 9: { bool _r = _t->slotFileSaveAs();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 10: _t->slotFilePrint(); break;
        case 11: _t->slotFilePreEnc(); break;
        case 12: _t->slotFilePreDec(); break;
        case 13: _t->slotKeyManager(); break;
        case 14: _t->slotFileClose(); break;
        case 15: _t->slotundo(); break;
        case 16: _t->slotredo(); break;
        case 17: _t->slotEditCut(); break;
        case 18: _t->slotEditCopy(); break;
        case 19: _t->slotEditPaste(); break;
        case 20: _t->slotSelectAll(); break;
        case 21: _t->slotFind(); break;
        case 22: _t->slotFindNext(); break;
        case 23: _t->slotFindPrev(); break;
        case 24: _t->slotFindText(); break;
        case 25: _t->slotSetCharset(); break;
        case 26: _t->slotResetEncoding((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 27: { bool _r = _t->checkEncoding((*reinterpret_cast< QTextCodec*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 28: _t->slotPreSignFile(); break;
        case 29: _t->slotSignFile((*reinterpret_cast< const KUrl(*)>(_a[1]))); break;
        case 30: _t->slotSignFileFin(); break;
        case 31: _t->slotPreVerifyFile(); break;
        case 32: _t->slotVerifyFile((*reinterpret_cast< const KUrl(*)>(_a[1]))); break;
        case 33: _t->slotCheckMd5(); break;
        case 34: _t->importSignatureKey((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 35: _t->slotOptions(); break;
        case 36: _t->slotUndoAvailable((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 37: _t->slotRedoAvailable((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 38: _t->slotCopyAvailable((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 39: _t->modified(); break;
        case 40: _t->newText(); break;
        case 41: _t->slotLibraryDone(); break;
        case 42: _t->slotDownloadKeysFinished((*reinterpret_cast< QStringList(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObjectExtraData KgpgEditor::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject KgpgEditor::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_KgpgEditor,
      qt_meta_data_KgpgEditor, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &KgpgEditor::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *KgpgEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *KgpgEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_KgpgEditor))
        return static_cast<void*>(const_cast< KgpgEditor*>(this));
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KgpgEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    }
    return _id;
}

// SIGNAL 0
void KgpgEditor::openChangeFont()
{
    QMetaObject::activate(this, &staticMetaObject, 0, 0);
}

// SIGNAL 1
void KgpgEditor::openConfigDialog()
{
    QMetaObject::activate(this, &staticMetaObject, 1, 0);
}
QT_END_MOC_NAMESPACE
