#include <kdialog.h>
#include <klocale.h>

/********************************************************************************
** Form generated from reading UI file 'searchres.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEARCHRES_H
#define UI_SEARCHRES_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QTreeView>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_searchRes
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *statusText;
    QHBoxLayout *hboxLayout;
    QLabel *filterEditLabel;
    KLineEdit *filterEdit;
    QTreeView *kLVsearch;
    QHBoxLayout *hboxLayout1;
    QLabel *textLabel1;
    KLineEdit *kLEID;

    void setupUi(QWidget *searchRes)
    {
        if (searchRes->objectName().isEmpty())
            searchRes->setObjectName(QString::fromUtf8("searchRes"));
        searchRes->resize(446, 262);
        vboxLayout = new QVBoxLayout(searchRes);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        statusText = new QLabel(searchRes);
        statusText->setObjectName(QString::fromUtf8("statusText"));
        statusText->setWordWrap(false);

        vboxLayout->addWidget(statusText);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        filterEditLabel = new QLabel(searchRes);
        filterEditLabel->setObjectName(QString::fromUtf8("filterEditLabel"));
        filterEditLabel->setWordWrap(true);

        hboxLayout->addWidget(filterEditLabel);

        filterEdit = new KLineEdit(searchRes);
        filterEdit->setObjectName(QString::fromUtf8("filterEdit"));
        filterEdit->setClearButtonShown(true);

        hboxLayout->addWidget(filterEdit);


        vboxLayout->addLayout(hboxLayout);

        kLVsearch = new QTreeView(searchRes);
        kLVsearch->setObjectName(QString::fromUtf8("kLVsearch"));
        kLVsearch->setAllColumnsShowFocus(true);
        kLVsearch->setSortingEnabled(true);
        kLVsearch->setRootIsDecorated(true);

        vboxLayout->addWidget(kLVsearch);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName(QString::fromUtf8("hboxLayout1"));
        textLabel1 = new QLabel(searchRes);
        textLabel1->setObjectName(QString::fromUtf8("textLabel1"));
        textLabel1->setWordWrap(false);

        hboxLayout1->addWidget(textLabel1);

        kLEID = new KLineEdit(searchRes);
        kLEID->setObjectName(QString::fromUtf8("kLEID"));
        kLEID->setClearButtonShown(true);

        hboxLayout1->addWidget(kLEID);


        vboxLayout->addLayout(hboxLayout1);

        QWidget::setTabOrder(kLVsearch, kLEID);

        retranslateUi(searchRes);

        QMetaObject::connectSlotsByName(searchRes);
    } // setupUi

    void retranslateUi(QWidget *searchRes)
    {
        statusText->setText(QString());
        filterEditLabel->setText(tr2i18n("Search:", 0));
        textLabel1->setText(tr2i18n("Key to import:", 0));
        Q_UNUSED(searchRes);
    } // retranslateUi

};

namespace Ui {
    class searchRes: public Ui_searchRes {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SEARCHRES_H

