/****************************************************************************
** Meta object code from reading C++ file 'keyservers.h'
**
** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kgpg-16.08.3/keyservers.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keyservers.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 63
#error "This file was generated using the moc from 4.8.7. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_KeyServer[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
      20,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: signature, parameters, type, tag, flags
      11,   10,   10,   10, 0x05,
      39,   10,   10,   10, 0x05,

 // slots: signature, parameters, type, tag, flags
      54,   10,   10,   10, 0x0a,
      74,   67,   10,   10, 0x0a,
     103,   98,   10,   10, 0x0a,
     124,   98,   10,   10, 0x0a,
     154,  149,   10,   10, 0x0a,
     189,  186,   10,   10, 0x0a,
     212,  186,   10,   10, 0x0a,
     242,  235,   10,   10, 0x0a,
     268,   10,   10,   10, 0x0a,
     284,   10,   10,   10, 0x0a,
     300,   10,   10,   10, 0x0a,
     316,   10,   10,   10, 0x0a,
     325,   10,   10,   10, 0x0a,
     349,  338,   10,   10, 0x08,
     379,  338,   10,   10, 0x08,
     414,  407,   10,   10, 0x08,
     436,   10,   10,   10, 0x08,
     460,  449,   10,   10, 0x08,

       0        // eod
};

static const char qt_meta_stringdata_KeyServer[] = {
    "KeyServer\0\0importFinished(QStringList)\0"
    "importFailed()\0slotImport()\0keyIds\0"
    "slotExport(QStringList)\0text\0"
    "slotSetText(QString)\0slotTextChanged(QString)\0"
    "attr\0slotSetExportAttribute(QString)\0"
    "on\0slotEnableProxyI(bool)\0"
    "slotEnableProxyE(bool)\0server\0"
    "slotSetKeyserver(QString)\0transferKeyID()\0"
    "slotPreImport()\0slotPreExport()\0"
    "slotOk()\0handleQuit()\0resultcode\0"
    "slotDownloadKeysFinished(int)\0"
    "slotUploadKeysFinished(int)\0result\0"
    "slotSearchResult(int)\0slotSearch()\0"
    "expression\0slotSetFilterString(QString)\0"
};

void KeyServer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Q_ASSERT(staticMetaObject.cast(_o));
        KeyServer *_t = static_cast<KeyServer *>(_o);
        switch (_id) {
        case 0: _t->importFinished((*reinterpret_cast< QStringList(*)>(_a[1]))); break;
        case 1: _t->importFailed(); break;
        case 2: _t->slotImport(); break;
        case 3: _t->slotExport((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 4: _t->slotSetText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->slotTextChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->slotSetExportAttribute((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->slotEnableProxyI((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 8: _t->slotEnableProxyE((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 9: _t->slotSetKeyserver((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->transferKeyID(); break;
        case 11: _t->slotPreImport(); break;
        case 12: _t->slotPreExport(); break;
        case 13: _t->slotOk(); break;
        case 14: _t->handleQuit(); break;
        case 15: _t->slotDownloadKeysFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->slotUploadKeysFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->slotSearchResult((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->slotSearch(); break;
        case 19: _t->slotSetFilterString((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObjectExtraData KeyServer::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject KeyServer::staticMetaObject = {
    { &KDialog::staticMetaObject, qt_meta_stringdata_KeyServer,
      qt_meta_data_KeyServer, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &KeyServer::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *KeyServer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *KeyServer::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_KeyServer))
        return static_cast<void*>(const_cast< KeyServer*>(this));
    return KDialog::qt_metacast(_clname);
}

int KeyServer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void KeyServer::importFinished(QStringList _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KeyServer::importFailed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, 0);
}
QT_END_MOC_NAMESPACE
