#include <kdialog.h>
#include <klocale.h>

/********************************************************************************
** Form generated from reading UI file 'conf_misc.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONF_MISC_H
#define UI_CONF_MISC_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QCheckBox>
#include <QtGui/QGroupBox>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QSpacerItem>
#include <QtGui/QSpinBox>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include "kcombobox.h"
#include "ktabwidget.h"
#include "ktextedit.h"

QT_BEGIN_NAMESPACE

class Ui_MiscConf
{
public:
    QVBoxLayout *vboxLayout;
    KTabWidget *miscWidget;
    QWidget *tabGlobal;
    QVBoxLayout *vboxLayout1;
    QVBoxLayout *vboxLayout2;
    QCheckBox *kcfg_AutoStart;
    QCheckBox *kcfg_UseMouseSelection;
    QCheckBox *kcfg_RemoteFileWarn;
    QSpacerItem *spacerItem;
    QWidget *tabApplet;
    QVBoxLayout *vboxLayout3;
    QGroupBox *groupBox11;
    QVBoxLayout *vboxLayout4;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel1;
    KComboBox *kcfg_SignMenu;
    QHBoxLayout *hboxLayout1;
    QLabel *textLabel1_3;
    KComboBox *kcfg_DecryptMenu;
    QGroupBox *groupBox3;
    QVBoxLayout *vboxLayout5;
    QCheckBox *kcfg_ShowSystray;
    QHBoxLayout *hboxLayout2;
    QLabel *textLabel1_2;
    KComboBox *kcfg_LeftClick;
    QSpacerItem *spacerItem1;
    QWidget *tabEditor;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpinBox *kcfg_RecentFiles;
    QSpacerItem *verticalSpacer;
    QWidget *tabSigning;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    KComboBox *kcfg_MailUats;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_3;
    KTextEdit *EmailTemplateEdit;

    void setupUi(QWidget *MiscConf)
    {
        if (MiscConf->objectName().isEmpty())
            MiscConf->setObjectName(QString::fromUtf8("MiscConf"));
        MiscConf->resize(680, 411);
        vboxLayout = new QVBoxLayout(MiscConf);
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        miscWidget = new KTabWidget(MiscConf);
        miscWidget->setObjectName(QString::fromUtf8("miscWidget"));
        tabGlobal = new QWidget();
        tabGlobal->setObjectName(QString::fromUtf8("tabGlobal"));
        vboxLayout1 = new QVBoxLayout(tabGlobal);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setObjectName(QString::fromUtf8("vboxLayout2"));
        kcfg_AutoStart = new QCheckBox(tabGlobal);
        kcfg_AutoStart->setObjectName(QString::fromUtf8("kcfg_AutoStart"));
        kcfg_AutoStart->setChecked(false);

        vboxLayout2->addWidget(kcfg_AutoStart);

        kcfg_UseMouseSelection = new QCheckBox(tabGlobal);
        kcfg_UseMouseSelection->setObjectName(QString::fromUtf8("kcfg_UseMouseSelection"));
        kcfg_UseMouseSelection->setMinimumSize(QSize(0, 0));

        vboxLayout2->addWidget(kcfg_UseMouseSelection);

        kcfg_RemoteFileWarn = new QCheckBox(tabGlobal);
        kcfg_RemoteFileWarn->setObjectName(QString::fromUtf8("kcfg_RemoteFileWarn"));
        kcfg_RemoteFileWarn->setMinimumSize(QSize(0, 0));

        vboxLayout2->addWidget(kcfg_RemoteFileWarn);


        vboxLayout1->addLayout(vboxLayout2);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout1->addItem(spacerItem);

        miscWidget->addTab(tabGlobal, QString());
        tabApplet = new QWidget();
        tabApplet->setObjectName(QString::fromUtf8("tabApplet"));
        vboxLayout3 = new QVBoxLayout(tabApplet);
        vboxLayout3->setObjectName(QString::fromUtf8("vboxLayout3"));
        groupBox11 = new QGroupBox(tabApplet);
        groupBox11->setObjectName(QString::fromUtf8("groupBox11"));
        vboxLayout4 = new QVBoxLayout(groupBox11);
        vboxLayout4->setObjectName(QString::fromUtf8("vboxLayout4"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        textLabel1 = new QLabel(groupBox11);
        textLabel1->setObjectName(QString::fromUtf8("textLabel1"));
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(textLabel1->sizePolicy().hasHeightForWidth());
        textLabel1->setSizePolicy(sizePolicy);
        textLabel1->setWordWrap(false);

        hboxLayout->addWidget(textLabel1);

        kcfg_SignMenu = new KComboBox(groupBox11);
        kcfg_SignMenu->setObjectName(QString::fromUtf8("kcfg_SignMenu"));
        sizePolicy.setHeightForWidth(kcfg_SignMenu->sizePolicy().hasHeightForWidth());
        kcfg_SignMenu->setSizePolicy(sizePolicy);

        hboxLayout->addWidget(kcfg_SignMenu);


        vboxLayout4->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName(QString::fromUtf8("hboxLayout1"));
        textLabel1_3 = new QLabel(groupBox11);
        textLabel1_3->setObjectName(QString::fromUtf8("textLabel1_3"));
        sizePolicy.setHeightForWidth(textLabel1_3->sizePolicy().hasHeightForWidth());
        textLabel1_3->setSizePolicy(sizePolicy);
        textLabel1_3->setWordWrap(false);

        hboxLayout1->addWidget(textLabel1_3);

        kcfg_DecryptMenu = new KComboBox(groupBox11);
        kcfg_DecryptMenu->setObjectName(QString::fromUtf8("kcfg_DecryptMenu"));

        hboxLayout1->addWidget(kcfg_DecryptMenu);


        vboxLayout4->addLayout(hboxLayout1);


        vboxLayout3->addWidget(groupBox11);

        groupBox3 = new QGroupBox(tabApplet);
        groupBox3->setObjectName(QString::fromUtf8("groupBox3"));
        vboxLayout5 = new QVBoxLayout(groupBox3);
        vboxLayout5->setObjectName(QString::fromUtf8("vboxLayout5"));
        kcfg_ShowSystray = new QCheckBox(groupBox3);
        kcfg_ShowSystray->setObjectName(QString::fromUtf8("kcfg_ShowSystray"));
        kcfg_ShowSystray->setChecked(true);

        vboxLayout5->addWidget(kcfg_ShowSystray);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName(QString::fromUtf8("hboxLayout2"));
        textLabel1_2 = new QLabel(groupBox3);
        textLabel1_2->setObjectName(QString::fromUtf8("textLabel1_2"));
        textLabel1_2->setWordWrap(false);

        hboxLayout2->addWidget(textLabel1_2);

        kcfg_LeftClick = new KComboBox(groupBox3);
        kcfg_LeftClick->setObjectName(QString::fromUtf8("kcfg_LeftClick"));
        QSizePolicy sizePolicy1(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kcfg_LeftClick->sizePolicy().hasHeightForWidth());
        kcfg_LeftClick->setSizePolicy(sizePolicy1);

        hboxLayout2->addWidget(kcfg_LeftClick);


        vboxLayout5->addLayout(hboxLayout2);


        vboxLayout3->addWidget(groupBox3);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout3->addItem(spacerItem1);

        miscWidget->addTab(tabApplet, QString());
        tabEditor = new QWidget();
        tabEditor->setObjectName(QString::fromUtf8("tabEditor"));
        verticalLayout = new QVBoxLayout(tabEditor);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label = new QLabel(tabEditor);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout->addWidget(label);

        kcfg_RecentFiles = new QSpinBox(tabEditor);
        kcfg_RecentFiles->setObjectName(QString::fromUtf8("kcfg_RecentFiles"));

        horizontalLayout->addWidget(kcfg_RecentFiles);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        miscWidget->addTab(tabEditor, QString());
        tabSigning = new QWidget();
        tabSigning->setObjectName(QString::fromUtf8("tabSigning"));
        verticalLayout_2 = new QVBoxLayout(tabSigning);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label_2 = new QLabel(tabSigning);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        horizontalLayout_2->addWidget(label_2);

        kcfg_MailUats = new KComboBox(tabSigning);
        kcfg_MailUats->setObjectName(QString::fromUtf8("kcfg_MailUats"));

        horizontalLayout_2->addWidget(kcfg_MailUats);


        verticalLayout_2->addLayout(horizontalLayout_2);

        groupBox = new QGroupBox(tabSigning);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        verticalLayout_3 = new QVBoxLayout(groupBox);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        EmailTemplateEdit = new KTextEdit(groupBox);
        EmailTemplateEdit->setObjectName(QString::fromUtf8("EmailTemplateEdit"));

        verticalLayout_3->addWidget(EmailTemplateEdit);


        verticalLayout_2->addWidget(groupBox);

        miscWidget->addTab(tabSigning, QString());

        vboxLayout->addWidget(miscWidget);


        retranslateUi(MiscConf);

        miscWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(MiscConf);
    } // setupUi

    void retranslateUi(QWidget *MiscConf)
    {
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_AutoStart->setWhatsThis(tr2i18n("<qt><b>Start KGpg automatically at KDE startup:</b><br />\n"
"<p>If checked KGpg will start automatically each time that KDE starts up.</p></qt>", 0));
#endif // QT_NO_WHATSTHIS
        kcfg_AutoStart->setText(tr2i18n("Start KGpg automatically at login", 0));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_UseMouseSelection->setWhatsThis(tr2i18n("<qt><b>Use mouse selection instead of clipboard:</b><br />\n"
"<p>If checked, clipboard operations in KGpg will use the selection clipboard, that means highlighting a text to copy, and middle button (or right+left together) to paste. If this option is not checked, the clipboard will work with Key shortcuts (Ctrl-c, Ctrl-v).</p></qt> ", 0));
#endif // QT_NO_WHATSTHIS
        kcfg_UseMouseSelection->setText(tr2i18n("Use mouse selection instead of clipboard", 0));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_RemoteFileWarn->setWhatsThis(tr2i18n("<qt><b>Display warning before creating temporary files:</b><br />\n"
"<p></p></qt>", 0));
#endif // QT_NO_WHATSTHIS
        kcfg_RemoteFileWarn->setText(tr2i18n("Display warning before creating temporary files\n"
"(only occurs on remote files operations)", 0));
        miscWidget->setTabText(miscWidget->indexOf(tabGlobal), tr2i18n("Global Settings", 0));
        groupBox11->setTitle(tr2i18n("Konqueror Service Menus", 0));
#ifndef UI_QT_NO_WHATSTHIS
        textLabel1->setWhatsThis(tr2i18n("<qt><b>Sign file service menu:</b><br />\n"
"<p></p>\n"
"</qt>", 0));
#endif // QT_NO_WHATSTHIS
        textLabel1->setText(tr2i18n("Sign file service menu:", 0));
        kcfg_SignMenu->clear();
        kcfg_SignMenu->insertItems(0, QStringList()
         << tr2i18n("Disable", 0)
         << tr2i18n("Enable with All Files", 0)
        );
#ifndef UI_QT_NO_WHATSTHIS
        textLabel1_3->setWhatsThis(tr2i18n("<qt><b>Decrypt file service menu:</b><br />\n"
"<p></p>\n"
"</qt>", 0));
#endif // QT_NO_WHATSTHIS
        textLabel1_3->setText(tr2i18n("Decrypt file service menu:", 0));
        kcfg_DecryptMenu->clear();
        kcfg_DecryptMenu->insertItems(0, QStringList()
         << tr2i18n("Disable", 0)
         << tr2i18n("Enable with All Files", 0)
         << tr2i18n("Enable with Encrypted Files", 0)
        );
        groupBox3->setTitle(tr2i18n("System Tray Applet", 0));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_ShowSystray->setWhatsThis(tr2i18n("<qt><b>Show system tray icon:</b><br />\n"
"<p>If checked KGpg will minimize to an icon in the system tray.</p></qt>", 0));
#endif // QT_NO_WHATSTHIS
        kcfg_ShowSystray->setText(tr2i18n("Show system tray icon", 0));
        textLabel1_2->setText(tr2i18n("Left mouse click opens:", 0));
        kcfg_LeftClick->clear();
        kcfg_LeftClick->insertItems(0, QStringList()
         << tr2i18n("Key Manager", 0)
         << tr2i18n("Editor", 0)
        );
        miscWidget->setTabText(miscWidget->indexOf(tabApplet), tr2i18n("Applet && Menus", 0));
        label->setText(tr2i18n("Recent files", 0));
        miscWidget->setTabText(miscWidget->indexOf(tabEditor), tr2i18n("Editor", 0));
#ifndef UI_QT_NO_WHATSTHIS
        label_2->setWhatsThis(tr2i18n("Here you can define how User Ids that do not contain an email address (like Photo Ids) are sent to the key owner. You can choose to either send them with every other User Id you signed, only with the first Id you signed or to not send them at all.", 0));
#endif // QT_NO_WHATSTHIS
        label_2->setText(tr2i18n("Mailing of User Ids without Email Addresses", 0));
        kcfg_MailUats->clear();
        kcfg_MailUats->insertItems(0, QStringList()
         << tr2i18n("Send with every Email", 0)
         << tr2i18n("Send only with first Email", 0)
         << tr2i18n("Do not send", 0)
        );
        groupBox->setTitle(tr2i18n("Email template", 0));
#ifndef UI_QT_NO_WHATSTHIS
        EmailTemplateEdit->setWhatsThis(tr2i18n("This is the text of the email sent by the \"Sign and Mail User ID\" action.\n"
"\n"
"The placeholders surrounded by the percent signs (like %KEYID%) will be replaced with the corresponding text for every single mail.", 0));
#endif // QT_NO_WHATSTHIS
        miscWidget->setTabText(miscWidget->indexOf(tabSigning), tr2i18n("Key Signing", 0));
        Q_UNUSED(MiscConf);
    } // retranslateUi

};

namespace Ui {
    class MiscConf: public Ui_MiscConf {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONF_MISC_H

