/****************************************************************************
** Meta object code from reading C++ file 'keysmanager.h'
**
** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kgpg-16.08.3/keysmanager.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keysmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 63
#error "This file was generated using the moc from 4.8.7. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_KeysManager[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
     100,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: signature, parameters, type, tag, flags
      13,   12,   12,   12, 0x05,
      32,   12,   12,   12, 0x05,
      53,   12,   12,   12, 0x05,
      66,   12,   12,   12, 0x05,

 // slots: signature, parameters, type, tag, flags
      85,   12,   12,   12, 0x0a,
     103,   12,   12,   12, 0x0a,
     116,   12,   12,   12, 0x0a,
     139,  133,   12,   12, 0x0a,
     166,  160,   12,   12, 0x0a,
     193,   12,   12,   12, 0x0a,
     222,  215,  210,   12, 0x0a,
     261,  247,  210,   12, 0x0a,
     296,  215,  210,   12, 0x2a,
     326,   12,   12,   12, 0x0a,
     342,   12,   12,   12, 0x0a,
     356,   12,   12,   12, 0x0a,
     378,  373,   12,   12, 0x0a,
     404,  398,   12,   12, 0x0a,
     427,   12,   12,   12, 0x0a,
     441,   12,   12,   12, 0x0a,
     455,   12,   12,   12, 0x0a,
     470,  466,   12,   12, 0x0a,
     494,  490,   12,   12, 0x0a,
     523,  519,   12,   12, 0x08,
     550,   12,   12,   12, 0x08,
     566,   12,   12,   12, 0x08,
     581,   12,   12,   12, 0x08,
     600,   12,   12,   12, 0x08,
     625,  621,   12,   12, 0x08,
     644,  621,   12,   12, 0x08,
     670,   12,   12,   12, 0x08,
     680,   12,   12,   12, 0x08,
     701,   12,   12,   12, 0x08,
     725,   12,   12,   12, 0x08,
     746,   12,   12,   12, 0x08,
     759,   12,   12,   12, 0x08,
     779,   12,   12,   12, 0x08,
     800,  793,   12,   12, 0x08,
     821,   12,   12,   12, 0x08,
     839,  834,   12,   12, 0x08,
     865,   12,   12,   12, 0x08,
     883,   12,   12,   12, 0x08,
     901,   12,   12,   12, 0x08,
     916,  621,   12,   12, 0x08,
     947,  942,   12,   12, 0x08,
     969,   12,   12,   12, 0x08,
     985,   12,   12,   12, 0x08,
    1000,  793,   12,   12, 0x08,
    1030,  793,   12,   12, 0x08,
    1059, 1055,   12,   12, 0x08,
    1076,   12,   12,   12, 0x08,
    1088,   12,   12,   12, 0x08,
    1102,   12,   12,   12, 0x08,
    1112,  793,   12,   12, 0x08,
    1136,  793,   12,   12, 0x08,
    1163,  793,   12,   12, 0x08,
    1190,   12,   12,   12, 0x08,
    1204,   12,   12,   12, 0x08,
    1220,   12,   12,   12, 0x08,
    1239,   12,   12,   12, 0x08,
    1254,   12,   12,   12, 0x08,
    1264,   12,   12,   12, 0x08,
    1274,   12,   12,   12, 0x08,
    1281,   12,   12,   12, 0x08,
    1296,   12,   12,   12, 0x08,
    1309,   12,   12,   12, 0x08,
    1328,   12,   12,   12, 0x08,
    1355, 1347,   12,   12, 0x08,
    1376, 1347,   12,   12, 0x08,
    1400,   12,   12,   12, 0x08,
    1427,   12,   12,   12, 0x08,
    1452,   12,   12,   12, 0x08,
    1472,   12,   12,   12, 0x08,
    1498,   12,   12,   12, 0x08,
    1514,   12,   12,   12, 0x08,
    1527,   12,   12,   12, 0x08,
    1543,  793,   12,   12, 0x08,
    1570,   12,   12,   12, 0x08,
    1587,   12,   12,   12, 0x08,
    1606,   12,   12,   12, 0x08,
    1622,   12,   12,   12, 0x08,
    1633,   12,   12,   12, 0x08,
    1644,  519,   12,   12, 0x08,
    1679,   12,   12,   12, 0x08,
    1691,   12,   12,   12, 0x08,
    1708,   12,   12,   12, 0x08,
    1722,   12,   12,   12, 0x08,
    1747, 1736,   12,   12, 0x08,
    1776,   12,   12,   12, 0x08,
    1799,  793,   12,   12, 0x08,
    1823,   12,   12,   12, 0x08,
    1840,   12,   12,   12, 0x08,
    1877, 1862,   12,   12, 0x08,
    1943, 1934,   12,   12, 0x08,
    1961,  793,   12,   12, 0x08,
    1987,  466,   12,   12, 0x08,
    2007,  793,   12,   12, 0x08,
    2024,   12,   12,   12, 0x08,
    2041,   12,   12,   12, 0x08,
    2057,   12,   12,   12, 0x08,

       0        // eod
};

static const char qt_meta_stringdata_KeysManager[] = {
    "KeysManager\0\0readAgainOptions()\0"
    "certificate(QString)\0closeAsked()\0"
    "fontChanged(QFont)\0slotGenerateKey()\0"
    "refreshkey()\0readAllOptions()\0keyID\0"
    "showKeyInfo(QString)\0newID\0"
    "slotSetDefaultKey(QString)\0showKeyManager()\0"
    "bool\0keyIDs\0importRemoteKey(QString)\0"
    "keyIDs,dialog\0importRemoteKeys(QStringList,bool)\0"
    "importRemoteKeys(QStringList)\0"
    "showKeyServer()\0showOptions()\0"
    "slotOpenEditor()\0text\0slotImport(QString)\0"
    "files\0slotImport(KUrl::List)\0clipEncrypt()\0"
    "clipDecrypt()\0clipSign()\0ret\0"
    "slotImportDone(int)\0ids\0"
    "refreshKeys(QStringList)\0job\0"
    "slotGenerateKeyDone(KJob*)\0slotShowTrust()\0"
    "slotShowSize()\0slotShowCreation()\0"
    "slotShowExpiration()\0res\0slotAddUidFin(int)\0"
    "slotDelPhotoFinished(int)\0quitApp()\0"
    "slotShowLongId(bool)\0slotSetTrustFilter(int)\0"
    "slotGotoDefaultKey()\0slotDelUid()\0"
    "slotDelUidDone(int)\0slotPrimUid()\0"
    "result\0slotPrimUidDone(int)\0slotAddUid()\0"
    "name\0slotAddUidEnable(QString)\0"
    "slotUpdatePhoto()\0slotDeletePhoto()\0"
    "slotAddPhoto()\0slotAddPhotoFinished(int)\0"
    "size\0slotSetPhotoSize(int)\0slotShowPhoto()\0"
    "revokeWidget()\0slotRevokeDialogFinished(int)\0"
    "slotRevokeGenerated(int)\0txt\0"
    "doPrint(QString)\0checkList()\0slotManpage()\0"
    "slotTip()\0slotExportFinished(int)\0"
    "slotProcessExportMail(int)\0"
    "slotProcessExportClip(int)\0readOptions()\0"
    "slotSetDefKey()\0confirmdeletekey()\0"
    "deleteseckey()\0signkey()\0signuid()\0"
    "caff()\0slotCaffDone()\0delsignkey()\0"
    "preimportsignkey()\0importallsignkey()\0"
    "success\0signatureResult(int)\0"
    "delsignatureResult(int)\0"
    "defaultAction(QModelIndex)\0"
    "defaultAction(KGpgNode*)\0slotDefaultAction()\0"
    "showProperties(KGpgNode*)\0keyproperties()\0"
    "slotexport()\0slotexportsec()\0"
    "slotExportSecFinished(int)\0slotMenu(QPoint)\0"
    "slotPreImportKey()\0slotSendEmail()\0"
    "slotedit()\0addToKAB()\0"
    "slotAddressbookSearchResult(KJob*)\0"
    "editGroup()\0createNewGroup()\0deleteGroup()\0"
    "renameGroup()\0revokeText\0"
    "slotImportRevokeTxt(QString)\0"
    "refreshKeyFromServer()\0slotKeyRefreshDone(int)\0"
    "slotregenerate()\0secretKeyDeleted(int)\0"
    "missingKeys,nd\0"
    "getMissingSigs(QSet<QString>&,const KGpgExpandableNode*)\0"
    "exitcode\0slotEditDone(int)\0"
    "importRemoteFinished(int)\0slotDelKeyDone(int)\0"
    "slotSetClip(int)\0slotOpenKeyUrl()\0"
    "slotNetworkUp()\0slotNetworkDown()\0"
};

void KeysManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Q_ASSERT(staticMetaObject.cast(_o));
        KeysManager *_t = static_cast<KeysManager *>(_o);
        switch (_id) {
        case 0: _t->readAgainOptions(); break;
        case 1: _t->certificate((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 2: _t->closeAsked(); break;
        case 3: _t->fontChanged((*reinterpret_cast< QFont(*)>(_a[1]))); break;
        case 4: _t->slotGenerateKey(); break;
        case 5: _t->refreshkey(); break;
        case 6: _t->readAllOptions(); break;
        case 7: _t->showKeyInfo((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->slotSetDefaultKey((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->showKeyManager(); break;
        case 10: { bool _r = _t->importRemoteKey((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 11: { bool _r = _t->importRemoteKeys((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const bool(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 12: { bool _r = _t->importRemoteKeys((*reinterpret_cast< const QStringList(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 13: _t->showKeyServer(); break;
        case 14: _t->showOptions(); break;
        case 15: _t->slotOpenEditor(); break;
        case 16: _t->slotImport((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 17: _t->slotImport((*reinterpret_cast< const KUrl::List(*)>(_a[1]))); break;
        case 18: _t->clipEncrypt(); break;
        case 19: _t->clipDecrypt(); break;
        case 20: _t->clipSign(); break;
        case 21: _t->slotImportDone((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 22: _t->refreshKeys((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 23: _t->slotGenerateKeyDone((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 24: _t->slotShowTrust(); break;
        case 25: _t->slotShowSize(); break;
        case 26: _t->slotShowCreation(); break;
        case 27: _t->slotShowExpiration(); break;
        case 28: _t->slotAddUidFin((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 29: _t->slotDelPhotoFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 30: _t->quitApp(); break;
        case 31: _t->slotShowLongId((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 32: _t->slotSetTrustFilter((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 33: _t->slotGotoDefaultKey(); break;
        case 34: _t->slotDelUid(); break;
        case 35: _t->slotDelUidDone((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 36: _t->slotPrimUid(); break;
        case 37: _t->slotPrimUidDone((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 38: _t->slotAddUid(); break;
        case 39: _t->slotAddUidEnable((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 40: _t->slotUpdatePhoto(); break;
        case 41: _t->slotDeletePhoto(); break;
        case 42: _t->slotAddPhoto(); break;
        case 43: _t->slotAddPhotoFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 44: _t->slotSetPhotoSize((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 45: _t->slotShowPhoto(); break;
        case 46: _t->revokeWidget(); break;
        case 47: _t->slotRevokeDialogFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 48: _t->slotRevokeGenerated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 49: _t->doPrint((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 50: _t->checkList(); break;
        case 51: _t->slotManpage(); break;
        case 52: _t->slotTip(); break;
        case 53: _t->slotExportFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 54: _t->slotProcessExportMail((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 55: _t->slotProcessExportClip((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 56: _t->readOptions(); break;
        case 57: _t->slotSetDefKey(); break;
        case 58: _t->confirmdeletekey(); break;
        case 59: _t->deleteseckey(); break;
        case 60: _t->signkey(); break;
        case 61: _t->signuid(); break;
        case 62: _t->caff(); break;
        case 63: _t->slotCaffDone(); break;
        case 64: _t->delsignkey(); break;
        case 65: _t->preimportsignkey(); break;
        case 66: _t->importallsignkey(); break;
        case 67: _t->signatureResult((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 68: _t->delsignatureResult((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 69: _t->defaultAction((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 70: _t->defaultAction((*reinterpret_cast< KGpgNode*(*)>(_a[1]))); break;
        case 71: _t->slotDefaultAction(); break;
        case 72: _t->showProperties((*reinterpret_cast< KGpgNode*(*)>(_a[1]))); break;
        case 73: _t->keyproperties(); break;
        case 74: _t->slotexport(); break;
        case 75: _t->slotexportsec(); break;
        case 76: _t->slotExportSecFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 77: _t->slotMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 78: _t->slotPreImportKey(); break;
        case 79: _t->slotSendEmail(); break;
        case 80: _t->slotedit(); break;
        case 81: _t->addToKAB(); break;
        case 82: _t->slotAddressbookSearchResult((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 83: _t->editGroup(); break;
        case 84: _t->createNewGroup(); break;
        case 85: _t->deleteGroup(); break;
        case 86: _t->renameGroup(); break;
        case 87: _t->slotImportRevokeTxt((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 88: _t->refreshKeyFromServer(); break;
        case 89: _t->slotKeyRefreshDone((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 90: _t->slotregenerate(); break;
        case 91: _t->secretKeyDeleted((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 92: _t->getMissingSigs((*reinterpret_cast< QSet<QString>(*)>(_a[1])),(*reinterpret_cast< const KGpgExpandableNode*(*)>(_a[2]))); break;
        case 93: _t->slotEditDone((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 94: _t->importRemoteFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 95: _t->slotDelKeyDone((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 96: _t->slotSetClip((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 97: _t->slotOpenKeyUrl(); break;
        case 98: _t->slotNetworkUp(); break;
        case 99: _t->slotNetworkDown(); break;
        default: ;
        }
    }
}

const QMetaObjectExtraData KeysManager::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject KeysManager::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_KeysManager,
      qt_meta_data_KeysManager, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &KeysManager::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *KeysManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *KeysManager::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_KeysManager))
        return static_cast<void*>(const_cast< KeysManager*>(this));
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KeysManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 100)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 100;
    }
    return _id;
}

// SIGNAL 0
void KeysManager::readAgainOptions()
{
    QMetaObject::activate(this, &staticMetaObject, 0, 0);
}

// SIGNAL 1
void KeysManager::certificate(QString _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KeysManager::closeAsked()
{
    QMetaObject::activate(this, &staticMetaObject, 2, 0);
}

// SIGNAL 3
void KeysManager::fontChanged(QFont _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_END_MOC_NAMESPACE
