#include <kdialog.h>
#include <klocale.h>

/********************************************************************************
** Form generated from reading UI file 'conf_ui2.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONF_UI2_H
#define UI_CONF_UI2_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QFormLayout>
#include <QtGui/QGridLayout>
#include <QtGui/QGroupBox>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QSpacerItem>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include <kcombobox.h>
#include "kcolorbutton.h"
#include "ktabwidget.h"

QT_BEGIN_NAMESPACE

class Ui_UIConf
{
public:
    QGridLayout *gridLayout;
    KTabWidget *tabWidget3;
    QWidget *tab;
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout1;
    QLabel *textLabel_trustUltimate;
    QLabel *textLabel_trustTrusted;
    QLabel *textLabel_trustMarginally;
    QLabel *textLabel_trustExpired;
    QLabel *textLabel_trustRevoked;
    QLabel *textLabel_trustUnknown;
    QLabel *textLabel_trustDisabled;
    QVBoxLayout *vboxLayout2;
    KColorButton *kcfg_ColorUltimate;
    KColorButton *kcfg_ColorGood;
    KColorButton *kcfg_ColorMarginal;
    KColorButton *kcfg_ColorExpired;
    KColorButton *kcfg_ColorRev;
    KColorButton *kcfg_ColorUnknown;
    KColorButton *kcfg_ColorBad;
    QSpacerItem *spacerItem;
    QWidget *TabPage;
    QWidget *tabKeyList;
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBoxSorting;
    QFormLayout *formLayout;
    QLabel *label_EmailSorting;
    KComboBox *kcfg_EmailSorting;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *UIConf)
    {
        if (UIConf->objectName().isEmpty())
            UIConf->setObjectName(QString::fromUtf8("UIConf"));
        UIConf->resize(833, 472);
        gridLayout = new QGridLayout(UIConf);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        tabWidget3 = new KTabWidget(UIConf);
        tabWidget3->setObjectName(QString::fromUtf8("tabWidget3"));
        tab = new QWidget();
        tab->setObjectName(QString::fromUtf8("tab"));
        vboxLayout = new QVBoxLayout(tab);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        textLabel_trustUltimate = new QLabel(tab);
        textLabel_trustUltimate->setObjectName(QString::fromUtf8("textLabel_trustUltimate"));
        textLabel_trustUltimate->setWordWrap(false);

        vboxLayout1->addWidget(textLabel_trustUltimate);

        textLabel_trustTrusted = new QLabel(tab);
        textLabel_trustTrusted->setObjectName(QString::fromUtf8("textLabel_trustTrusted"));
        textLabel_trustTrusted->setWordWrap(false);

        vboxLayout1->addWidget(textLabel_trustTrusted);

        textLabel_trustMarginally = new QLabel(tab);
        textLabel_trustMarginally->setObjectName(QString::fromUtf8("textLabel_trustMarginally"));
        textLabel_trustMarginally->setWordWrap(false);

        vboxLayout1->addWidget(textLabel_trustMarginally);

        textLabel_trustExpired = new QLabel(tab);
        textLabel_trustExpired->setObjectName(QString::fromUtf8("textLabel_trustExpired"));
        textLabel_trustExpired->setWordWrap(false);

        vboxLayout1->addWidget(textLabel_trustExpired);

        textLabel_trustRevoked = new QLabel(tab);
        textLabel_trustRevoked->setObjectName(QString::fromUtf8("textLabel_trustRevoked"));
        textLabel_trustRevoked->setWordWrap(false);

        vboxLayout1->addWidget(textLabel_trustRevoked);

        textLabel_trustUnknown = new QLabel(tab);
        textLabel_trustUnknown->setObjectName(QString::fromUtf8("textLabel_trustUnknown"));
        textLabel_trustUnknown->setWordWrap(false);

        vboxLayout1->addWidget(textLabel_trustUnknown);

        textLabel_trustDisabled = new QLabel(tab);
        textLabel_trustDisabled->setObjectName(QString::fromUtf8("textLabel_trustDisabled"));
        textLabel_trustDisabled->setWordWrap(false);

        vboxLayout1->addWidget(textLabel_trustDisabled);


        hboxLayout->addLayout(vboxLayout1);

        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setObjectName(QString::fromUtf8("vboxLayout2"));
        kcfg_ColorUltimate = new KColorButton(tab);
        kcfg_ColorUltimate->setObjectName(QString::fromUtf8("kcfg_ColorUltimate"));
        kcfg_ColorUltimate->setColor(QColor(68, 0, 255));

        vboxLayout2->addWidget(kcfg_ColorUltimate);

        kcfg_ColorGood = new KColorButton(tab);
        kcfg_ColorGood->setObjectName(QString::fromUtf8("kcfg_ColorGood"));
        kcfg_ColorGood->setColor(QColor(144, 255, 0));

        vboxLayout2->addWidget(kcfg_ColorGood);

        kcfg_ColorMarginal = new KColorButton(tab);
        kcfg_ColorMarginal->setObjectName(QString::fromUtf8("kcfg_ColorMarginal"));
        kcfg_ColorMarginal->setColor(QColor(255, 255, 0));

        vboxLayout2->addWidget(kcfg_ColorMarginal);

        kcfg_ColorExpired = new KColorButton(tab);
        kcfg_ColorExpired->setObjectName(QString::fromUtf8("kcfg_ColorExpired"));
        kcfg_ColorExpired->setColor(QColor(150, 150, 150));

        vboxLayout2->addWidget(kcfg_ColorExpired);

        kcfg_ColorRev = new KColorButton(tab);
        kcfg_ColorRev->setObjectName(QString::fromUtf8("kcfg_ColorRev"));
        kcfg_ColorRev->setColor(QColor(30, 30, 30));

        vboxLayout2->addWidget(kcfg_ColorRev);

        kcfg_ColorUnknown = new KColorButton(tab);
        kcfg_ColorUnknown->setObjectName(QString::fromUtf8("kcfg_ColorUnknown"));

        vboxLayout2->addWidget(kcfg_ColorUnknown);

        kcfg_ColorBad = new KColorButton(tab);
        kcfg_ColorBad->setObjectName(QString::fromUtf8("kcfg_ColorBad"));
        kcfg_ColorBad->setColor(QColor(172, 0, 0));

        vboxLayout2->addWidget(kcfg_ColorBad);


        hboxLayout->addLayout(vboxLayout2);


        vboxLayout->addLayout(hboxLayout);

        spacerItem = new QSpacerItem(402, 121, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(spacerItem);

        tabWidget3->addTab(tab, QString());
        TabPage = new QWidget();
        TabPage->setObjectName(QString::fromUtf8("TabPage"));
        tabWidget3->addTab(TabPage, QString());
        tabKeyList = new QWidget();
        tabKeyList->setObjectName(QString::fromUtf8("tabKeyList"));
        verticalLayout = new QVBoxLayout(tabKeyList);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        groupBoxSorting = new QGroupBox(tabKeyList);
        groupBoxSorting->setObjectName(QString::fromUtf8("groupBoxSorting"));
        formLayout = new QFormLayout(groupBoxSorting);
        formLayout->setObjectName(QString::fromUtf8("formLayout"));
        label_EmailSorting = new QLabel(groupBoxSorting);
        label_EmailSorting->setObjectName(QString::fromUtf8("label_EmailSorting"));

        formLayout->setWidget(0, QFormLayout::LabelRole, label_EmailSorting);

        kcfg_EmailSorting = new KComboBox(groupBoxSorting);
        kcfg_EmailSorting->setObjectName(QString::fromUtf8("kcfg_EmailSorting"));

        formLayout->setWidget(0, QFormLayout::FieldRole, kcfg_EmailSorting);


        verticalLayout->addWidget(groupBoxSorting);

        verticalSpacer = new QSpacerItem(20, 351, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        tabWidget3->addTab(tabKeyList, QString());

        gridLayout->addWidget(tabWidget3, 0, 0, 1, 1);

#ifndef UI_QT_NO_SHORTCUT
        label_EmailSorting->setBuddy(kcfg_EmailSorting);
#endif // QT_NO_SHORTCUT

        retranslateUi(UIConf);

        tabWidget3->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(UIConf);
    } // setupUi

    void retranslateUi(QWidget *UIConf)
    {
        textLabel_trustUltimate->setText(tr2i18n("Ultimately trusted keys:", 0));
        textLabel_trustTrusted->setText(tr2i18n("Trusted keys:", 0));
        textLabel_trustMarginally->setText(tr2i18n("Marginally trusted keys:", 0));
        textLabel_trustExpired->setText(tr2i18n("Expired keys:", 0));
        textLabel_trustRevoked->setText(tr2i18n("Revoked keys:", 0));
        textLabel_trustUnknown->setText(tr2i18n("Unknown keys:", 0));
        textLabel_trustDisabled->setText(tr2i18n("Disabled keys:", 0));
        kcfg_ColorUltimate->setText(QString());
        kcfg_ColorGood->setText(QString());
        kcfg_ColorMarginal->setText(QString());
        kcfg_ColorExpired->setText(QString());
        kcfg_ColorRev->setText(QString());
        kcfg_ColorUnknown->setText(QString());
        kcfg_ColorBad->setText(QString());
        tabWidget3->setTabText(tabWidget3->indexOf(tab), tr2i18n("Key Colors", 0));
        tabWidget3->setTabText(tabWidget3->indexOf(TabPage), tr2i18n("Editor Font", 0));
        groupBoxSorting->setTitle(tr2i18n("Sort Order", 0));
        label_EmailSorting->setText(tr2i18n("Email:", 0));
        tabWidget3->setTabText(tabWidget3->indexOf(tabKeyList), tr2i18n("Key List", 0));
        Q_UNUSED(UIConf);
    } // retranslateUi

};

namespace Ui {
    class UIConf: public Ui_UIConf {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONF_UI2_H

