/****************************************************************************
** Meta object code from reading C++ file 'kgpgexternalactions.h'
**
** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kgpg-16.08.3/kgpgexternalactions.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgpgexternalactions.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 63
#error "This file was generated using the moc from 4.8.7. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_KGpgExternalActions[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: signature, parameters, type, tag, flags
      21,   20,   20,   20, 0x05,
      36,   20,   20,   20, 0x05,

 // slots: signature, parameters, type, tag, flags
      59,   20,   20,   20, 0x08,
      79,   20,   20,   20, 0x08,
     108,  101,   20,   20, 0x08,
     134,   20,   20,   20, 0x08,
     141,   20,   20,   20, 0x08,
     158,  155,   20,   20, 0x08,
     189,  182,   20,   20, 0x08,
     217,  213,   20,   20, 0x08,
     243,   20,   20,   20, 0x08,
     259,   20,   20,   20, 0x08,

       0        // eod
};

static const char qt_meta_stringdata_KGpgExternalActions[] = {
    "KGpgExternalActions\0\0createNewKey()\0"
    "updateDefault(QString)\0startFolderEncode()\0"
    "slotSaveOptionsPath()\0result\0"
    "slotVerificationDone(int)\0help()\0"
    "readOptions()\0cp\0slotSetCompression(int)\0"
    "status\0slotDecryptionDone(int)\0job\0"
    "slotFolderFinished(KJob*)\0slotSignFiles()\0"
    "slotEncryptionKeySelected()\0"
};

void KGpgExternalActions::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Q_ASSERT(staticMetaObject.cast(_o));
        KGpgExternalActions *_t = static_cast<KGpgExternalActions *>(_o);
        switch (_id) {
        case 0: _t->createNewKey(); break;
        case 1: _t->updateDefault((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 2: _t->startFolderEncode(); break;
        case 3: _t->slotSaveOptionsPath(); break;
        case 4: _t->slotVerificationDone((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->help(); break;
        case 6: _t->readOptions(); break;
        case 7: _t->slotSetCompression((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->slotDecryptionDone((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->slotFolderFinished((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 10: _t->slotSignFiles(); break;
        case 11: _t->slotEncryptionKeySelected(); break;
        default: ;
        }
    }
}

const QMetaObjectExtraData KGpgExternalActions::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject KGpgExternalActions::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KGpgExternalActions,
      qt_meta_data_KGpgExternalActions, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &KGpgExternalActions::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *KGpgExternalActions::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *KGpgExternalActions::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_KGpgExternalActions))
        return static_cast<void*>(const_cast< KGpgExternalActions*>(this));
    return QObject::qt_metacast(_clname);
}

int KGpgExternalActions::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void KGpgExternalActions::createNewKey()
{
    QMetaObject::activate(this, &staticMetaObject, 0, 0);
}

// SIGNAL 1
void KGpgExternalActions::updateDefault(QString _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_END_MOC_NAMESPACE
