/*
 * This file was generated by qdbusxml2cpp version 0.7
 * Command line was: qdbusxml2cpp -m -p kgpg_interface /usr/src/ports/kgpg/kgpg-16.08.3-1.x86_64/src/kgpg-16.08.3/org.kde.kgpg.Key.xml
 *
 * qdbusxml2cpp is Copyright (C) 2015 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#include "kgpg_interface.h"

/*
 * Implementation of interface class OrgKdeKgpgKeyInterface
 */

OrgKdeKgpgKeyInterface::OrgKdeKgpgKeyInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgKdeKgpgKeyInterface::~OrgKdeKgpgKeyInterface()
{
}


#include "kgpg_interface.moc"
