#include <kdialog.h>
#include <klocale.h>

/********************************************************************************
** Form generated from reading UI file 'conf_gpg.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONF_GPG_H
#define UI_CONF_GPG_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QCheckBox>
#include <QtGui/QGridLayout>
#include <QtGui/QGroupBox>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QPushButton>
#include <QtGui/QSpacerItem>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_GPGConf
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox2;
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout1;
    QLabel *textLabel1_5_2;
    QLabel *textLabel1_5_2_2;
    QGridLayout *gridLayout;
    KLineEdit *gpg_home_path;
    QSpacerItem *spacerItem;
    KLineEdit *gpg_conf_path;
    QPushButton *changeHome;
    QGroupBox *groupBox3;
    QHBoxLayout *hboxLayout1;
    QLabel *textLabel1_6_2;
    QGridLayout *gridLayout1;
    KLineEdit *kcfg_GpgBinaryPath;
    QSpacerItem *spacerItem1;
    QCheckBox *use_agent;
    QSpacerItem *spacerItem2;

    void setupUi(QWidget *GPGConf)
    {
        if (GPGConf->objectName().isEmpty())
            GPGConf->setObjectName(QString::fromUtf8("GPGConf"));
        GPGConf->resize(592, 343);
        vboxLayout = new QVBoxLayout(GPGConf);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        groupBox2 = new QGroupBox(GPGConf);
        groupBox2->setObjectName(QString::fromUtf8("groupBox2"));
        hboxLayout = new QHBoxLayout(groupBox2);
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        textLabel1_5_2 = new QLabel(groupBox2);
        textLabel1_5_2->setObjectName(QString::fromUtf8("textLabel1_5_2"));
        textLabel1_5_2->setWordWrap(false);

        vboxLayout1->addWidget(textLabel1_5_2);

        textLabel1_5_2_2 = new QLabel(groupBox2);
        textLabel1_5_2_2->setObjectName(QString::fromUtf8("textLabel1_5_2_2"));
        textLabel1_5_2_2->setWordWrap(false);

        vboxLayout1->addWidget(textLabel1_5_2_2);


        hboxLayout->addLayout(vboxLayout1);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gpg_home_path = new KLineEdit(groupBox2);
        gpg_home_path->setObjectName(QString::fromUtf8("gpg_home_path"));
        gpg_home_path->setEnabled(true);
        gpg_home_path->setReadOnly(true);

        gridLayout->addWidget(gpg_home_path, 0, 0, 1, 1);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Preferred, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem, 1, 1, 1, 2);

        gpg_conf_path = new KLineEdit(groupBox2);
        gpg_conf_path->setObjectName(QString::fromUtf8("gpg_conf_path"));
        gpg_conf_path->setEnabled(true);
        gpg_conf_path->setReadOnly(true);

        gridLayout->addWidget(gpg_conf_path, 1, 0, 1, 1);

        changeHome = new QPushButton(groupBox2);
        changeHome->setObjectName(QString::fromUtf8("changeHome"));

        gridLayout->addWidget(changeHome, 0, 1, 1, 2);


        hboxLayout->addLayout(gridLayout);


        vboxLayout->addWidget(groupBox2);

        groupBox3 = new QGroupBox(GPGConf);
        groupBox3->setObjectName(QString::fromUtf8("groupBox3"));
        hboxLayout1 = new QHBoxLayout(groupBox3);
        hboxLayout1->setObjectName(QString::fromUtf8("hboxLayout1"));
        textLabel1_6_2 = new QLabel(groupBox3);
        textLabel1_6_2->setObjectName(QString::fromUtf8("textLabel1_6_2"));
        textLabel1_6_2->setWordWrap(false);

        hboxLayout1->addWidget(textLabel1_6_2);

        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName(QString::fromUtf8("gridLayout1"));
        kcfg_GpgBinaryPath = new KLineEdit(groupBox3);
        kcfg_GpgBinaryPath->setObjectName(QString::fromUtf8("kcfg_GpgBinaryPath"));
        kcfg_GpgBinaryPath->setEnabled(true);

        gridLayout1->addWidget(kcfg_GpgBinaryPath, 0, 0, 1, 1);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Preferred, QSizePolicy::Minimum);

        gridLayout1->addItem(spacerItem1, 0, 1, 1, 2);


        hboxLayout1->addLayout(gridLayout1);


        vboxLayout->addWidget(groupBox3);

        use_agent = new QCheckBox(GPGConf);
        use_agent->setObjectName(QString::fromUtf8("use_agent"));

        vboxLayout->addWidget(use_agent);

        spacerItem2 = new QSpacerItem(569, 181, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(spacerItem2);


        retranslateUi(GPGConf);

        QMetaObject::connectSlotsByName(GPGConf);
    } // setupUi

    void retranslateUi(QWidget *GPGConf)
    {
#ifndef UI_QT_NO_WHATSTHIS
        GPGConf->setWhatsThis(tr2i18n("<qt><b>Global Settings:</b><br />\n"
"<p></p>\n"
"</qt>", 0));
#endif // QT_NO_WHATSTHIS
        groupBox2->setTitle(tr2i18n("GnuPG Home", 0));
#ifndef UI_QT_NO_WHATSTHIS
        textLabel1_5_2->setWhatsThis(tr2i18n("<b>Home Location</b><p>This is the directory where GnuPG stores its configuration and the keyrings. If you have not changed it this is usually <em>~/.gnupg/</em></p>", 0));
#endif // QT_NO_WHATSTHIS
        textLabel1_5_2->setText(tr2i18n("Home location:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        textLabel1_5_2_2->setWhatsThis(tr2i18n("<b>Configuration File</b><p>This is the name of the configuration file in the directory specified above. The default is <em>gnupg.conf</em> while older versions of GnuPG used <em>options</em>.</p>", 0));
#endif // QT_NO_WHATSTHIS
        textLabel1_5_2_2->setText(tr2i18n("Configuration file:", 0));
        changeHome->setText(tr2i18n("Change...", 0));
        groupBox3->setTitle(tr2i18n("GnuPG Binary", 0));
#ifndef UI_QT_NO_WHATSTHIS
        textLabel1_6_2->setWhatsThis(tr2i18n("<b>Program path</b><p>This is the program that will be called for all GnuPG operations. The default of <em>gpg</em> will work on most systems.</p>", 0));
#endif // QT_NO_WHATSTHIS
        textLabel1_6_2->setText(tr2i18n("Program path:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        use_agent->setWhatsThis(tr2i18n("<b>Use GnuPG agent</b><p>The GnuPG agent stores the passwords for your secret keys in memory for a limited amount of time. If you use your secret key again while it is cached you do not have to enter it again. This is less secure than typing it every time.</p>", 0));
#endif // QT_NO_WHATSTHIS
        use_agent->setText(tr2i18n("Use GnuPG agent", 0));
    } // retranslateUi

};

namespace Ui {
    class GPGConf: public Ui_GPGConf {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONF_GPG_H

