/****************************************************************************
** Meta object code from reading C++ file 'caff_p.h'
**
** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kgpg-16.08.3/caff_p.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'caff_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 63
#error "This file was generated using the moc from 4.8.7. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_KGpgCaffPrivate[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: signature, parameters, type, tag, flags
      24,   17,   16,   16, 0x08,
      49,   17,   16,   16, 0x08,
      73,   17,   16,   16, 0x08,
      97,   17,   16,   16, 0x08,
     120,   17,   16,   16, 0x08,

       0        // eod
};

static const char qt_meta_stringdata_KGpgCaffPrivate[] = {
    "KGpgCaffPrivate\0\0result\0"
    "slotSigningFinished(int)\0"
    "slotDelUidFinished(int)\0slotExportFinished(int)\0"
    "slotTextEncrypted(int)\0slotReimportDone(int)\0"
};

void KGpgCaffPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Q_ASSERT(staticMetaObject.cast(_o));
        KGpgCaffPrivate *_t = static_cast<KGpgCaffPrivate *>(_o);
        switch (_id) {
        case 0: _t->slotSigningFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->slotDelUidFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->slotExportFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->slotTextEncrypted((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->slotReimportDone((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObjectExtraData KGpgCaffPrivate::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject KGpgCaffPrivate::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KGpgCaffPrivate,
      qt_meta_data_KGpgCaffPrivate, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &KGpgCaffPrivate::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *KGpgCaffPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *KGpgCaffPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_KGpgCaffPrivate))
        return static_cast<void*>(const_cast< KGpgCaffPrivate*>(this));
    return QObject::qt_metacast(_clname);
}

int KGpgCaffPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
