/****************************************************************************
** Meta object code from reading C++ file 'kgpgtextedit.h'
**
** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kgpg-16.08.3/editor/kgpgtextedit.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgpgtextedit.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 63
#error "This file was generated using the moc from 4.8.7. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_KgpgTextEdit[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: signature, parameters, type, tag, flags
      14,   13,   13,   13, 0x05,
      24,   13,   13,   13, 0x05,
      44,   13,   13,   13, 0x05,

 // slots: signature, parameters, type, tag, flags
      65,   61,   13,   13, 0x0a,
      87,   13,   13,   13, 0x0a,
     100,   13,   13,   13, 0x0a,
     121,  113,   13,   13, 0x0a,
     139,  113,   13,   13, 0x0a,
     159,   13,   13,   13, 0x0a,
     205,  176,   13,   13, 0x0a,
     247,  240,   13,   13, 0x0a,
     267,  240,   13,   13, 0x08,
     289,  240,   13,   13, 0x08,
     309,  240,   13,   13, 0x08,

       0        // eod
};

static const char qt_meta_stringdata_KgpgTextEdit[] = {
    "KgpgTextEdit\0\0newText()\0resetEncoding(bool)\0"
    "verifyFinished()\0url\0slotDroppedFile(KUrl)\0"
    "slotEncode()\0slotDecode()\0message\0"
    "slotSign(QString)\0slotVerify(QString)\0"
    "slotSignVerify()\0,matchingindex,matchedlength\0"
    "slotHighlightText(QString,int,int)\0"
    "result\0slotVerifyDone(int)\0"
    "slotEncodeUpdate(int)\0slotSignUpdate(int)\0"
    "slotDecryptDone(int)\0"
};

void KgpgTextEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Q_ASSERT(staticMetaObject.cast(_o));
        KgpgTextEdit *_t = static_cast<KgpgTextEdit *>(_o);
        switch (_id) {
        case 0: _t->newText(); break;
        case 1: _t->resetEncoding((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->verifyFinished(); break;
        case 3: _t->slotDroppedFile((*reinterpret_cast< const KUrl(*)>(_a[1]))); break;
        case 4: _t->slotEncode(); break;
        case 5: _t->slotDecode(); break;
        case 6: _t->slotSign((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->slotVerify((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->slotSignVerify(); break;
        case 9: _t->slotHighlightText((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const int(*)>(_a[2])),(*reinterpret_cast< const int(*)>(_a[3]))); break;
        case 10: _t->slotVerifyDone((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->slotEncodeUpdate((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->slotSignUpdate((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->slotDecryptDone((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObjectExtraData KgpgTextEdit::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject KgpgTextEdit::staticMetaObject = {
    { &KTextEdit::staticMetaObject, qt_meta_stringdata_KgpgTextEdit,
      qt_meta_data_KgpgTextEdit, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &KgpgTextEdit::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *KgpgTextEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *KgpgTextEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_KgpgTextEdit))
        return static_cast<void*>(const_cast< KgpgTextEdit*>(this));
    return KTextEdit::qt_metacast(_clname);
}

int KgpgTextEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void KgpgTextEdit::newText()
{
    QMetaObject::activate(this, &staticMetaObject, 0, 0);
}

// SIGNAL 1
void KgpgTextEdit::resetEncoding(bool _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KgpgTextEdit::verifyFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, 0);
}
QT_END_MOC_NAMESPACE
