#include <kdialog.h>
#include <klocale.h>

/********************************************************************************
** Form generated from reading UI file 'kgpgrevokewidget.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KGPGREVOKEWIDGET_H
#define UI_KGPGREVOKEWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QCheckBox>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include "kcombobox.h"
#include "ktextedit.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_KgpgRevokeWidget
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel1;
    QLabel *keyID;
    QHBoxLayout *hboxLayout1;
    QLabel *textLabel3;
    KComboBox *comboBox1;
    QLabel *textLabel4;
    KTextEdit *textDescription;
    QHBoxLayout *hboxLayout2;
    QCheckBox *cbSave;
    KUrlRequester *outputFile;
    QCheckBox *cbPrint;
    QCheckBox *cbImport;

    void setupUi(QWidget *KgpgRevokeWidget)
    {
        if (KgpgRevokeWidget->objectName().isEmpty())
            KgpgRevokeWidget->setObjectName(QString::fromUtf8("KgpgRevokeWidget"));
        KgpgRevokeWidget->resize(472, 374);
        vboxLayout = new QVBoxLayout(KgpgRevokeWidget);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        textLabel1 = new QLabel(KgpgRevokeWidget);
        textLabel1->setObjectName(QString::fromUtf8("textLabel1"));
        textLabel1->setWordWrap(false);

        hboxLayout->addWidget(textLabel1);

        keyID = new QLabel(KgpgRevokeWidget);
        keyID->setObjectName(QString::fromUtf8("keyID"));
        keyID->setAlignment(Qt::AlignVCenter);
        keyID->setWordWrap(false);

        hboxLayout->addWidget(keyID);


        vboxLayout->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName(QString::fromUtf8("hboxLayout1"));
        textLabel3 = new QLabel(KgpgRevokeWidget);
        textLabel3->setObjectName(QString::fromUtf8("textLabel3"));
        textLabel3->setWordWrap(false);

        hboxLayout1->addWidget(textLabel3);

        comboBox1 = new KComboBox(KgpgRevokeWidget);
        comboBox1->setObjectName(QString::fromUtf8("comboBox1"));

        hboxLayout1->addWidget(comboBox1);


        vboxLayout->addLayout(hboxLayout1);

        textLabel4 = new QLabel(KgpgRevokeWidget);
        textLabel4->setObjectName(QString::fromUtf8("textLabel4"));
        textLabel4->setWordWrap(false);

        vboxLayout->addWidget(textLabel4);

        textDescription = new KTextEdit(KgpgRevokeWidget);
        textDescription->setObjectName(QString::fromUtf8("textDescription"));

        vboxLayout->addWidget(textDescription);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName(QString::fromUtf8("hboxLayout2"));
        cbSave = new QCheckBox(KgpgRevokeWidget);
        cbSave->setObjectName(QString::fromUtf8("cbSave"));
        cbSave->setChecked(true);

        hboxLayout2->addWidget(cbSave);

        outputFile = new KUrlRequester(KgpgRevokeWidget);
        outputFile->setObjectName(QString::fromUtf8("outputFile"));

        hboxLayout2->addWidget(outputFile);


        vboxLayout->addLayout(hboxLayout2);

        cbPrint = new QCheckBox(KgpgRevokeWidget);
        cbPrint->setObjectName(QString::fromUtf8("cbPrint"));

        vboxLayout->addWidget(cbPrint);

        cbImport = new QCheckBox(KgpgRevokeWidget);
        cbImport->setObjectName(QString::fromUtf8("cbImport"));
        cbImport->setEnabled(true);

        vboxLayout->addWidget(cbImport);

        QWidget::setTabOrder(comboBox1, textDescription);
        QWidget::setTabOrder(textDescription, cbSave);
        QWidget::setTabOrder(cbSave, cbPrint);
        QWidget::setTabOrder(cbPrint, cbImport);
        QWidget::setTabOrder(cbImport, outputFile);

        retranslateUi(KgpgRevokeWidget);

        QMetaObject::connectSlotsByName(KgpgRevokeWidget);
    } // setupUi

    void retranslateUi(QWidget *KgpgRevokeWidget)
    {
        textLabel1->setText(tr2i18n("Create revocation certificate for", 0));
        keyID->setText(tr2i18n("key id", 0));
        textLabel3->setText(tr2i18n("Reason for revocation:", 0));
        comboBox1->clear();
        comboBox1->insertItems(0, QStringList()
         << tr2i18n("No Reason", 0)
         << tr2i18n("Key Has Been Compromised", 0)
         << tr2i18n("Key is Superseded", 0)
         << tr2i18n("Key is No Longer Used", 0)
        );
        textLabel4->setText(tr2i18n("Description:", 0));
        cbSave->setText(tr2i18n("Save certificate:", 0));
        cbPrint->setText(tr2i18n("Print certificate", 0));
        cbImport->setText(tr2i18n("Import into keyring", 0));
        Q_UNUSED(KgpgRevokeWidget);
    } // retranslateUi

};

namespace Ui {
    class KgpgRevokeWidget: public Ui_KgpgRevokeWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KGPGREVOKEWIDGET_H

