#include <kdialog.h>
#include <klocale.h>

/********************************************************************************
** Form generated from reading UI file 'conf_encryption.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONF_ENCRYPTION_H
#define UI_CONF_ENCRYPTION_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QCheckBox>
#include <QtGui/QGridLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QSpacerItem>
#include <QtGui/QWidget>
#include "kcombobox.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_Encryption
{
public:
    QGridLayout *gridLayout;
    QCheckBox *kcfg_AsciiArmor;
    QCheckBox *kcfg_PgpExtension;
    QSpacerItem *spacer7;
    QCheckBox *kcfg_AllowCustomEncryptionOptions;
    KLineEdit *kcfg_CustomEncryptionOptions;
    KComboBox *always_key;
    KComboBox *file_key;
    QCheckBox *encrypt_to_always;
    QCheckBox *kcfg_EncryptFilesTo;
    QCheckBox *kcfg_AllowUntrustedKeys;
    QCheckBox *kcfg_AllowUntrustedGroupMembers;
    QCheckBox *kcfg_HideUserID;
    QCheckBox *kcfg_PgpCompatibility;

    void setupUi(QWidget *Encryption)
    {
        if (Encryption->objectName().isEmpty())
            Encryption->setObjectName(QString::fromUtf8("Encryption"));
        Encryption->resize(421, 280);
        gridLayout = new QGridLayout(Encryption);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        kcfg_AsciiArmor = new QCheckBox(Encryption);
        kcfg_AsciiArmor->setObjectName(QString::fromUtf8("kcfg_AsciiArmor"));
        kcfg_AsciiArmor->setMinimumSize(QSize(0, 0));

        gridLayout->addWidget(kcfg_AsciiArmor, 0, 0, 1, 3);

        kcfg_PgpExtension = new QCheckBox(Encryption);
        kcfg_PgpExtension->setObjectName(QString::fromUtf8("kcfg_PgpExtension"));

        gridLayout->addWidget(kcfg_PgpExtension, 11, 0, 1, 3);

        spacer7 = new QSpacerItem(20, 16, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(spacer7, 12, 1, 1, 1);

        kcfg_AllowCustomEncryptionOptions = new QCheckBox(Encryption);
        kcfg_AllowCustomEncryptionOptions->setObjectName(QString::fromUtf8("kcfg_AllowCustomEncryptionOptions"));

        gridLayout->addWidget(kcfg_AllowCustomEncryptionOptions, 10, 0, 1, 2);

        kcfg_CustomEncryptionOptions = new KLineEdit(Encryption);
        kcfg_CustomEncryptionOptions->setObjectName(QString::fromUtf8("kcfg_CustomEncryptionOptions"));
        kcfg_CustomEncryptionOptions->setEnabled(false);

        gridLayout->addWidget(kcfg_CustomEncryptionOptions, 10, 2, 1, 1);

        always_key = new KComboBox(Encryption);
        always_key->setObjectName(QString::fromUtf8("always_key"));
        always_key->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(always_key->sizePolicy().hasHeightForWidth());
        always_key->setSizePolicy(sizePolicy);

        gridLayout->addWidget(always_key, 8, 1, 1, 2);

        file_key = new KComboBox(Encryption);
        file_key->setObjectName(QString::fromUtf8("file_key"));
        file_key->setEnabled(false);
        sizePolicy.setHeightForWidth(file_key->sizePolicy().hasHeightForWidth());
        file_key->setSizePolicy(sizePolicy);

        gridLayout->addWidget(file_key, 9, 1, 1, 2);

        encrypt_to_always = new QCheckBox(Encryption);
        encrypt_to_always->setObjectName(QString::fromUtf8("encrypt_to_always"));

        gridLayout->addWidget(encrypt_to_always, 8, 0, 1, 1);

        kcfg_EncryptFilesTo = new QCheckBox(Encryption);
        kcfg_EncryptFilesTo->setObjectName(QString::fromUtf8("kcfg_EncryptFilesTo"));

        gridLayout->addWidget(kcfg_EncryptFilesTo, 9, 0, 1, 1);

        kcfg_AllowUntrustedKeys = new QCheckBox(Encryption);
        kcfg_AllowUntrustedKeys->setObjectName(QString::fromUtf8("kcfg_AllowUntrustedKeys"));

        gridLayout->addWidget(kcfg_AllowUntrustedKeys, 1, 0, 1, 3);

        kcfg_AllowUntrustedGroupMembers = new QCheckBox(Encryption);
        kcfg_AllowUntrustedGroupMembers->setObjectName(QString::fromUtf8("kcfg_AllowUntrustedGroupMembers"));

        gridLayout->addWidget(kcfg_AllowUntrustedGroupMembers, 5, 0, 1, 1);

        kcfg_HideUserID = new QCheckBox(Encryption);
        kcfg_HideUserID->setObjectName(QString::fromUtf8("kcfg_HideUserID"));

        gridLayout->addWidget(kcfg_HideUserID, 7, 0, 1, 1);

        kcfg_PgpCompatibility = new QCheckBox(Encryption);
        kcfg_PgpCompatibility->setObjectName(QString::fromUtf8("kcfg_PgpCompatibility"));

        gridLayout->addWidget(kcfg_PgpCompatibility, 6, 0, 1, 1);


        retranslateUi(Encryption);

        QMetaObject::connectSlotsByName(Encryption);
    } // setupUi

    void retranslateUi(QWidget *Encryption)
    {
        Encryption->setWindowTitle(tr2i18n("Encryption", 0));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_AsciiArmor->setWhatsThis(tr2i18n("<qt><b>ASCII armored encryption:</b> <br /> \n"
"<p>Checking this option outputs all encrypted files in a format that can be opened by a text editor and as such the output is suitable for placing in the body of an e-mail message.</p></qt>", 0));
#endif // QT_NO_WHATSTHIS
        kcfg_AsciiArmor->setText(tr2i18n("ASCII armored encryption", 0));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_PgpExtension->setWhatsThis(tr2i18n("<qt><b>Use *.pgp extension for encrypted files:</b><br />\n"
"<p>Checking this option will append a .pgp extension to all encrypted files instead of a .gpg extension. This option will maintain compatibility with users of PGP (Pretty Good Privacy) software.</p></qt>", 0));
#endif // QT_NO_WHATSTHIS
        kcfg_PgpExtension->setText(tr2i18n("Use *.pgp extension for encrypted files", 0));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_AllowCustomEncryptionOptions->setWhatsThis(tr2i18n("<qt><b>Custom encryption command:</b><br />\n"
"<p>When activated, an entry field will be shown in the key selection dialog, enabling you to enter a custom command for encryption. This option is recommended for experienced users only.</p></qt>", 0));
#endif // QT_NO_WHATSTHIS
        kcfg_AllowCustomEncryptionOptions->setText(tr2i18n("Custom encryption command:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        encrypt_to_always->setWhatsThis(tr2i18n("<qt><b>Always encrypt with:</b><br />\n"
"<p>This ensures all files/messages will also be encrypted with the chosen key. However, if the \"Encrypt files with:\" option is selected that chosen key will override the \"Always encrypt with:\" selection.</p></qt>", 0));
#endif // QT_NO_WHATSTHIS
        encrypt_to_always->setText(tr2i18n("Always encrypt with:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_EncryptFilesTo->setWhatsThis(tr2i18n("<qt><b>Encrypt files with:</b><br />\n"
"<p>Checking this option and selecting a key will force any file encryption operation to use the selected key. KGpg will not query for a recipient and the default key will be bypassed.</p></qt>", 0));
#endif // QT_NO_WHATSTHIS
        kcfg_EncryptFilesTo->setText(tr2i18n("Encrypt files with:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_AllowUntrustedKeys->setWhatsThis(tr2i18n("<qt><b>Allow encryption with untrusted keys:</b><br />\n"
"<p>When importing a public key, the key is usually marked as untrusted and as such cannot be used unless it is signed by the default key (thus making it 'trusted'). Checking this box enables any key to be used even if it is untrusted.</p></qt>", 0));
#endif // QT_NO_WHATSTHIS
        kcfg_AllowUntrustedKeys->setText(tr2i18n("Allow encryption with untrusted keys", 0));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_AllowUntrustedGroupMembers->setWhatsThis(tr2i18n("<qt><b>Allow untrusted keys as members of key groups:</b><br /><p>A key group allows simple encryption to multiple recipients at once. Similar to the <em>Allow encryption with untrusted keys</em> option this allows untrusted keys to become member of a key group.</p></qt>", 0));
#endif // QT_NO_WHATSTHIS
        kcfg_AllowUntrustedGroupMembers->setText(tr2i18n("Allow untrusted keys as members of key groups", 0));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_HideUserID->setWhatsThis(tr2i18n("<qt><b>Hide user ID:</b><br /> \n"
"<p>Checking this option will remove the keyid of the recipient from all encrypted packets. The advantage: traffic analysis of the encrypted packets cannot be performed as easily because the recipient is unknown. The disadvantage: the receiver of the encrypted packets is forced to try all secret keys before being able to decrypt the packets. This can be a lengthy process depending on the number of secret keys the receiver holds.</p></qt>", 0));
#endif // QT_NO_WHATSTHIS
        kcfg_HideUserID->setText(tr2i18n("Hide user id", 0));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_PgpCompatibility->setWhatsThis(tr2i18n("<qt><b>PGP 6 compatibility:</b><br /> \n"
"<p>Checking this option forces GnuPG to output encrypted packets that are as compliant with PGP (Pretty Good Privacy) 6 standards as possible thus allowing GnuPG users to inter operate with PGP 6 users.</p></qt>", 0));
#endif // QT_NO_WHATSTHIS
        kcfg_PgpCompatibility->setText(tr2i18n("PGP 6 compatibility", 0));
    } // retranslateUi

};

namespace Ui {
    class Encryption: public Ui_Encryption {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONF_ENCRYPTION_H

