#include <kdialog.h>
#include <klocale.h>

/********************************************************************************
** Form generated from reading UI file 'conf_servers.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONF_SERVERS_H
#define UI_CONF_SERVERS_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QCheckBox>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QListView>
#include <QtGui/QSpacerItem>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include "kpushbutton.h"

QT_BEGIN_NAMESPACE

class Ui_ServerConf
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout1;
    QListView *ServerBox;
    QLabel *textLabel1_4;
    QCheckBox *kcfg_UseProxy;
    QVBoxLayout *vboxLayout2;
    KPushButton *server_default;
    KPushButton *server_add;
    KPushButton *server_del;
    KPushButton *server_edit;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *ServerConf)
    {
        if (ServerConf->objectName().isEmpty())
            ServerConf->setObjectName(QString::fromUtf8("ServerConf"));
        ServerConf->resize(642, 294);
        vboxLayout = new QVBoxLayout(ServerConf);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        ServerBox = new QListView(ServerConf);
        ServerBox->setObjectName(QString::fromUtf8("ServerBox"));

        vboxLayout1->addWidget(ServerBox);

        textLabel1_4 = new QLabel(ServerConf);
        textLabel1_4->setObjectName(QString::fromUtf8("textLabel1_4"));
        textLabel1_4->setWordWrap(true);

        vboxLayout1->addWidget(textLabel1_4);

        kcfg_UseProxy = new QCheckBox(ServerConf);
        kcfg_UseProxy->setObjectName(QString::fromUtf8("kcfg_UseProxy"));

        vboxLayout1->addWidget(kcfg_UseProxy);


        hboxLayout->addLayout(vboxLayout1);

        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setObjectName(QString::fromUtf8("vboxLayout2"));
        server_default = new KPushButton(ServerConf);
        server_default->setObjectName(QString::fromUtf8("server_default"));
        server_default->setEnabled(false);

        vboxLayout2->addWidget(server_default);

        server_add = new KPushButton(ServerConf);
        server_add->setObjectName(QString::fromUtf8("server_add"));

        vboxLayout2->addWidget(server_add);

        server_del = new KPushButton(ServerConf);
        server_del->setObjectName(QString::fromUtf8("server_del"));
        server_del->setEnabled(false);

        vboxLayout2->addWidget(server_del);

        server_edit = new KPushButton(ServerConf);
        server_edit->setObjectName(QString::fromUtf8("server_edit"));

        vboxLayout2->addWidget(server_edit);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout2->addItem(spacerItem);


        hboxLayout->addLayout(vboxLayout2);


        vboxLayout->addLayout(hboxLayout);


        retranslateUi(ServerConf);

        QMetaObject::connectSlotsByName(ServerConf);
    } // setupUi

    void retranslateUi(QWidget *ServerConf)
    {
        textLabel1_4->setText(tr2i18n("<b>INFORMATION</b>:\n"
"Only the default server will be stored in GnuPG's configuration file,\n"
"all others will be stored for use by KGpg only.", 0));
        kcfg_UseProxy->setText(tr2i18n("Honor HTTP proxy when available", 0));
        server_default->setText(tr2i18n("&Set as Default", 0));
        server_add->setText(tr2i18n("&Add...", 0));
        server_del->setText(tr2i18n("&Delete", 0));
        server_edit->setText(tr2i18n("&Edit...", 0));
        Q_UNUSED(ServerConf);
    } // retranslateUi

};

namespace Ui {
    class ServerConf: public Ui_ServerConf {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONF_SERVERS_H

