#include <kdialog.h>
#include <klocale.h>

/********************************************************************************
** Form generated from reading UI file 'newkey.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NEWKEY_H
#define UI_NEWKEY_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QCheckBox>
#include <QtGui/QGroupBox>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QSpacerItem>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include "klineedit.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_newKey
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox2;
    QVBoxLayout *vboxLayout1;
    QLabel *textLabel2;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel3;
    QLabel *TLname;
    QHBoxLayout *hboxLayout1;
    QLabel *textLabel4;
    QLabel *TLemail;
    QHBoxLayout *hboxLayout2;
    QLabel *textLabel5;
    QLabel *TLid;
    QVBoxLayout *vboxLayout2;
    QLabel *textLabel6;
    KLineEdit *LEfinger;
    QCheckBox *CBdefault;
    QGroupBox *groupBox1;
    QVBoxLayout *vboxLayout3;
    QLabel *textLabel1;
    QHBoxLayout *hboxLayout3;
    QCheckBox *CBsave;
    KUrlRequester *kURLRequester1;
    QCheckBox *CBprint;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *newKey)
    {
        if (newKey->objectName().isEmpty())
            newKey->setObjectName(QString::fromUtf8("newKey"));
        newKey->resize(616, 489);
        vboxLayout = new QVBoxLayout(newKey);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        groupBox2 = new QGroupBox(newKey);
        groupBox2->setObjectName(QString::fromUtf8("groupBox2"));
        vboxLayout1 = new QVBoxLayout(groupBox2);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        textLabel2 = new QLabel(groupBox2);
        textLabel2->setObjectName(QString::fromUtf8("textLabel2"));
        textLabel2->setWordWrap(false);

        vboxLayout1->addWidget(textLabel2);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        textLabel3 = new QLabel(groupBox2);
        textLabel3->setObjectName(QString::fromUtf8("textLabel3"));
        textLabel3->setWordWrap(false);

        hboxLayout->addWidget(textLabel3);

        TLname = new QLabel(groupBox2);
        TLname->setObjectName(QString::fromUtf8("TLname"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(TLname->sizePolicy().hasHeightForWidth());
        TLname->setSizePolicy(sizePolicy);
        TLname->setWordWrap(false);

        hboxLayout->addWidget(TLname);


        vboxLayout1->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName(QString::fromUtf8("hboxLayout1"));
        textLabel4 = new QLabel(groupBox2);
        textLabel4->setObjectName(QString::fromUtf8("textLabel4"));
        textLabel4->setWordWrap(false);

        hboxLayout1->addWidget(textLabel4);

        TLemail = new QLabel(groupBox2);
        TLemail->setObjectName(QString::fromUtf8("TLemail"));
        TLemail->setWordWrap(false);

        hboxLayout1->addWidget(TLemail);


        vboxLayout1->addLayout(hboxLayout1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName(QString::fromUtf8("hboxLayout2"));
        textLabel5 = new QLabel(groupBox2);
        textLabel5->setObjectName(QString::fromUtf8("textLabel5"));
        textLabel5->setWordWrap(false);

        hboxLayout2->addWidget(textLabel5);

        TLid = new QLabel(groupBox2);
        TLid->setObjectName(QString::fromUtf8("TLid"));
        TLid->setWordWrap(false);

        hboxLayout2->addWidget(TLid);


        vboxLayout1->addLayout(hboxLayout2);

        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setObjectName(QString::fromUtf8("vboxLayout2"));
        textLabel6 = new QLabel(groupBox2);
        textLabel6->setObjectName(QString::fromUtf8("textLabel6"));
        textLabel6->setWordWrap(false);

        vboxLayout2->addWidget(textLabel6);

        LEfinger = new KLineEdit(groupBox2);
        LEfinger->setObjectName(QString::fromUtf8("LEfinger"));
        LEfinger->setFrame(true);
        LEfinger->setReadOnly(true);

        vboxLayout2->addWidget(LEfinger);

        CBdefault = new QCheckBox(groupBox2);
        CBdefault->setObjectName(QString::fromUtf8("CBdefault"));

        vboxLayout2->addWidget(CBdefault);


        vboxLayout1->addLayout(vboxLayout2);


        vboxLayout->addWidget(groupBox2);

        groupBox1 = new QGroupBox(newKey);
        groupBox1->setObjectName(QString::fromUtf8("groupBox1"));
        vboxLayout3 = new QVBoxLayout(groupBox1);
        vboxLayout3->setObjectName(QString::fromUtf8("vboxLayout3"));
        textLabel1 = new QLabel(groupBox1);
        textLabel1->setObjectName(QString::fromUtf8("textLabel1"));
        textLabel1->setWordWrap(false);

        vboxLayout3->addWidget(textLabel1);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setObjectName(QString::fromUtf8("hboxLayout3"));
        CBsave = new QCheckBox(groupBox1);
        CBsave->setObjectName(QString::fromUtf8("CBsave"));

        hboxLayout3->addWidget(CBsave);

        kURLRequester1 = new KUrlRequester(groupBox1);
        kURLRequester1->setObjectName(QString::fromUtf8("kURLRequester1"));
        kURLRequester1->setEnabled(false);

        hboxLayout3->addWidget(kURLRequester1);


        vboxLayout3->addLayout(hboxLayout3);

        CBprint = new QCheckBox(groupBox1);
        CBprint->setObjectName(QString::fromUtf8("CBprint"));

        vboxLayout3->addWidget(CBprint);


        vboxLayout->addWidget(groupBox1);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(spacerItem);


        retranslateUi(newKey);

        QMetaObject::connectSlotsByName(newKey);
    } // setupUi

    void retranslateUi(QWidget *newKey)
    {
        newKey->setWindowTitle(tr2i18n("New Key Pair Created", 0));
        groupBox2->setTitle(tr2i18n("New Key Created", 0));
        textLabel2->setText(tr2i18n("You have successfully created the following key:", 0));
        textLabel3->setText(tr2i18n("Name:", 0));
        TLname->setText(tr2i18n("textLabel7", "KDE::DoNotExtract"));
        textLabel4->setText(tr2i18n("Email:", 0));
        TLemail->setText(tr2i18n("textLabel8", "KDE::DoNotExtract"));
        textLabel5->setText(tr2i18n("Key ID:", 0));
        TLid->setText(tr2i18n("textLabel10", "KDE::DoNotExtract"));
        textLabel6->setText(tr2i18n("Fingerprint:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        CBdefault->setWhatsThis(tr2i18n("<qt><b>Set as your default key:</b><br />\n"
"<p>Checking this option sets the newly created key pair as the default key pair.</p></qt>", 0));
#endif // QT_NO_WHATSTHIS
        CBdefault->setText(tr2i18n("Set as your default key", 0));
        groupBox1->setTitle(tr2i18n("Revocation Certificate", 0));
        textLabel1->setText(tr2i18n("It is recommended to save or print a revocation certificate in case your key is compromised.", 0));
        CBsave->setText(tr2i18n("Save as:", 0));
        CBprint->setText(tr2i18n("Print", 0));
    } // retranslateUi

};

namespace Ui {
    class newKey: public Ui_newKey {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NEWKEY_H

