#include <kdialog.h>
#include <klocale.h>

/********************************************************************************
** Form generated from reading UI file 'sourceselect.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SOURCESELECT_H
#define UI_SOURCESELECT_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QGroupBox>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QRadioButton>
#include <QtGui/QSpacerItem>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include "klineedit.h"
#include "kpushbutton.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_SrcSelect
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *buttonGroup2;
    QVBoxLayout *vboxLayout1;
    QRadioButton *checkClipboard;
    QHBoxLayout *hboxLayout;
    QRadioButton *checkFile;
    KUrlRequester *newFilename;
    QHBoxLayout *hboxLayout1;
    QRadioButton *checkServer;
    KLineEdit *keyIds;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *SrcSelect)
    {
        if (SrcSelect->objectName().isEmpty())
            SrcSelect->setObjectName(QString::fromUtf8("SrcSelect"));
        SrcSelect->resize(380, 243);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SrcSelect->sizePolicy().hasHeightForWidth());
        SrcSelect->setSizePolicy(sizePolicy);
        SrcSelect->setMinimumSize(QSize(350, 0));
        vboxLayout = new QVBoxLayout(SrcSelect);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        buttonGroup2 = new QGroupBox(SrcSelect);
        buttonGroup2->setObjectName(QString::fromUtf8("buttonGroup2"));
        vboxLayout1 = new QVBoxLayout(buttonGroup2);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        checkClipboard = new QRadioButton(buttonGroup2);
        checkClipboard->setObjectName(QString::fromUtf8("checkClipboard"));

        vboxLayout1->addWidget(checkClipboard);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        checkFile = new QRadioButton(buttonGroup2);
        checkFile->setObjectName(QString::fromUtf8("checkFile"));
        checkFile->setChecked(true);

        hboxLayout->addWidget(checkFile);

        newFilename = new KUrlRequester(buttonGroup2);
        newFilename->setObjectName(QString::fromUtf8("newFilename"));
        newFilename->setEnabled(true);
        newFilename->setMode(KFile::File|KFile::ExistingOnly);

        hboxLayout->addWidget(newFilename);


        vboxLayout1->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName(QString::fromUtf8("hboxLayout1"));
        checkServer = new QRadioButton(buttonGroup2);
        checkServer->setObjectName(QString::fromUtf8("checkServer"));
        checkServer->setChecked(false);

        hboxLayout1->addWidget(checkServer);

        keyIds = new KLineEdit(buttonGroup2);
        keyIds->setObjectName(QString::fromUtf8("keyIds"));
        keyIds->setEnabled(false);

        hboxLayout1->addWidget(keyIds);


        vboxLayout1->addLayout(hboxLayout1);


        vboxLayout->addWidget(buttonGroup2);

        spacerItem = new QSpacerItem(331, 51, QSizePolicy::Minimum, QSizePolicy::Minimum);

        vboxLayout->addItem(spacerItem);


        retranslateUi(SrcSelect);

        QMetaObject::connectSlotsByName(SrcSelect);
    } // setupUi

    void retranslateUi(QWidget *SrcSelect)
    {
        buttonGroup2->setTitle(QString());
        checkClipboard->setText(tr2i18n("Clipboard", 0));
        checkFile->setText(tr2i18n("File:", 0));
        checkServer->setText(tr2i18n("Keyserver:", 0));
#ifndef UI_QT_NO_TOOLTIP
        keyIds->setToolTip(tr2i18n("Enter the ids or fingerprints of the keys to import as space separated list.", 0));
#endif // QT_NO_TOOLTIP
        Q_UNUSED(SrcSelect);
    } // retranslateUi

};

namespace Ui {
    class SrcSelect: public Ui_SrcSelect {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SOURCESELECT_H

