#include <kdialog.h>
#include <klocale.h>

/********************************************************************************
** Form generated from reading UI file 'kgpgKeyInfo.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KGPGKEYINFO_H
#define UI_KGPGKEYINFO_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QCheckBox>
#include <QtGui/QFormLayout>
#include <QtGui/QGroupBox>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QSpacerItem>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include "kcombobox.h"
#include "kdialog.h"
#include "kpushbutton.h"
#include "kurllabel.h"

QT_BEGIN_NAMESPACE

class Ui_kgpgKeyInfo
{
public:
    QWidget *page;
    QVBoxLayout *verticalLayout_5;
    QHBoxLayout *top;
    QGroupBox *gr_properties;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_2;
    QLabel *m_name;
    KUrlLabel *m_email;
    QSpacerItem *horizontalSpacer;
    QFormLayout *formLayout_keyproperties;
    QLabel *tl_id;
    QLabel *m_id;
    QLabel *tl_comment;
    QLabel *m_comment;
    QLabel *tl_creation;
    QLabel *m_creation;
    QLabel *tl_expiration;
    QLabel *m_expiration;
    QLabel *tl_trust;
    QLabel *tl_owtrust;
    KComboBox *m_owtrust;
    QLabel *tl_algorithm;
    QLabel *m_algorithm;
    QLabel *tl_length;
    QLabel *m_length;
    QLabel *tl_caps;
    QLabel *m_caps;
    QSpacerItem *verticalSpacer_2;
    QVBoxLayout *right;
    QGroupBox *gr_photo;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *m_photo;
    KComboBox *m_photoid;
    QSpacerItem *verticalSpacer;
    QGroupBox *gr_buttons;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *m_disable;
    KPushButton *m_expirationbtn;
    KPushButton *m_password;
    QGroupBox *gr_fingerprint;
    QVBoxLayout *verticalLayout_4;
    QLabel *m_fingerprint;

    void setupUi(KDialog *kgpgKeyInfo)
    {
        if (kgpgKeyInfo->objectName().isEmpty())
            kgpgKeyInfo->setObjectName(QString::fromUtf8("kgpgKeyInfo"));
        kgpgKeyInfo->resize(558, 488);
        kgpgKeyInfo->setModal(true);
        page = new QWidget(kgpgKeyInfo);
        page->setObjectName(QString::fromUtf8("page"));
        page->setGeometry(QRect(10, 20, 521, 431));
        verticalLayout_5 = new QVBoxLayout(page);
        verticalLayout_5->setObjectName(QString::fromUtf8("verticalLayout_5"));
        top = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        top->setContentsMargins(0, 0, 0, 0);
#endif
        top->setObjectName(QString::fromUtf8("top"));
        gr_properties = new QGroupBox(page);
        gr_properties->setObjectName(QString::fromUtf8("gr_properties"));
        verticalLayout = new QVBoxLayout(gr_properties);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        m_name = new QLabel(gr_properties);
        m_name->setObjectName(QString::fromUtf8("m_name"));
        m_name->setText(QString::fromUtf8(""));
        m_name->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        horizontalLayout_2->addWidget(m_name);

        m_email = new KUrlLabel(gr_properties);
        m_email->setObjectName(QString::fromUtf8("m_email"));
        m_email->setText(QString::fromUtf8(""));
        m_email->setTextInteractionFlags(Qt::TextSelectableByMouse);

        horizontalLayout_2->addWidget(m_email);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout_2);

        formLayout_keyproperties = new QFormLayout();
        formLayout_keyproperties->setObjectName(QString::fromUtf8("formLayout_keyproperties"));
        formLayout_keyproperties->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        tl_id = new QLabel(gr_properties);
        tl_id->setObjectName(QString::fromUtf8("tl_id"));

        formLayout_keyproperties->setWidget(0, QFormLayout::LabelRole, tl_id);

        m_id = new QLabel(gr_properties);
        m_id->setObjectName(QString::fromUtf8("m_id"));
        m_id->setText(QString::fromUtf8(""));
        m_id->setTextInteractionFlags(Qt::TextSelectableByMouse);

        formLayout_keyproperties->setWidget(0, QFormLayout::FieldRole, m_id);

        tl_comment = new QLabel(gr_properties);
        tl_comment->setObjectName(QString::fromUtf8("tl_comment"));

        formLayout_keyproperties->setWidget(1, QFormLayout::LabelRole, tl_comment);

        m_comment = new QLabel(gr_properties);
        m_comment->setObjectName(QString::fromUtf8("m_comment"));
        m_comment->setText(QString::fromUtf8(""));
        m_comment->setTextFormat(Qt::PlainText);
        m_comment->setTextInteractionFlags(Qt::TextSelectableByMouse);

        formLayout_keyproperties->setWidget(1, QFormLayout::FieldRole, m_comment);

        tl_creation = new QLabel(gr_properties);
        tl_creation->setObjectName(QString::fromUtf8("tl_creation"));

        formLayout_keyproperties->setWidget(2, QFormLayout::LabelRole, tl_creation);

        m_creation = new QLabel(gr_properties);
        m_creation->setObjectName(QString::fromUtf8("m_creation"));
        m_creation->setText(QString::fromUtf8(""));
        m_creation->setTextInteractionFlags(Qt::TextSelectableByMouse);

        formLayout_keyproperties->setWidget(2, QFormLayout::FieldRole, m_creation);

        tl_expiration = new QLabel(gr_properties);
        tl_expiration->setObjectName(QString::fromUtf8("tl_expiration"));

        formLayout_keyproperties->setWidget(3, QFormLayout::LabelRole, tl_expiration);

        m_expiration = new QLabel(gr_properties);
        m_expiration->setObjectName(QString::fromUtf8("m_expiration"));
        m_expiration->setText(QString::fromUtf8(""));
        m_expiration->setTextInteractionFlags(Qt::TextSelectableByMouse);

        formLayout_keyproperties->setWidget(3, QFormLayout::FieldRole, m_expiration);

        tl_trust = new QLabel(gr_properties);
        tl_trust->setObjectName(QString::fromUtf8("tl_trust"));

        formLayout_keyproperties->setWidget(4, QFormLayout::LabelRole, tl_trust);

        tl_owtrust = new QLabel(gr_properties);
        tl_owtrust->setObjectName(QString::fromUtf8("tl_owtrust"));

        formLayout_keyproperties->setWidget(5, QFormLayout::LabelRole, tl_owtrust);

        m_owtrust = new KComboBox(gr_properties);
        m_owtrust->setObjectName(QString::fromUtf8("m_owtrust"));
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_owtrust->sizePolicy().hasHeightForWidth());
        m_owtrust->setSizePolicy(sizePolicy);
        m_owtrust->setMinimumSize(QSize(128, 0));
        m_owtrust->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        formLayout_keyproperties->setWidget(5, QFormLayout::FieldRole, m_owtrust);

        tl_algorithm = new QLabel(gr_properties);
        tl_algorithm->setObjectName(QString::fromUtf8("tl_algorithm"));

        formLayout_keyproperties->setWidget(6, QFormLayout::LabelRole, tl_algorithm);

        m_algorithm = new QLabel(gr_properties);
        m_algorithm->setObjectName(QString::fromUtf8("m_algorithm"));
        m_algorithm->setText(QString::fromUtf8(""));
        m_algorithm->setTextInteractionFlags(Qt::TextSelectableByMouse);

        formLayout_keyproperties->setWidget(6, QFormLayout::FieldRole, m_algorithm);

        tl_length = new QLabel(gr_properties);
        tl_length->setObjectName(QString::fromUtf8("tl_length"));

        formLayout_keyproperties->setWidget(7, QFormLayout::LabelRole, tl_length);

        m_length = new QLabel(gr_properties);
        m_length->setObjectName(QString::fromUtf8("m_length"));
        m_length->setText(QString::fromUtf8(""));
        m_length->setTextInteractionFlags(Qt::TextSelectableByMouse);

        formLayout_keyproperties->setWidget(7, QFormLayout::FieldRole, m_length);

        tl_caps = new QLabel(gr_properties);
        tl_caps->setObjectName(QString::fromUtf8("tl_caps"));

        formLayout_keyproperties->setWidget(8, QFormLayout::LabelRole, tl_caps);

        m_caps = new QLabel(gr_properties);
        m_caps->setObjectName(QString::fromUtf8("m_caps"));
        QSizePolicy sizePolicy1(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_caps->sizePolicy().hasHeightForWidth());
        m_caps->setSizePolicy(sizePolicy1);
        m_caps->setTextFormat(Qt::PlainText);
        m_caps->setWordWrap(true);
        m_caps->setTextInteractionFlags(Qt::TextSelectableByMouse);

        formLayout_keyproperties->setWidget(8, QFormLayout::FieldRole, m_caps);


        verticalLayout->addLayout(formLayout_keyproperties);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);


        top->addWidget(gr_properties);

        right = new QVBoxLayout();
        right->setContentsMargins(5, 5, 5, 5);
        right->setObjectName(QString::fromUtf8("right"));
        right->setSizeConstraint(QLayout::SetMinAndMaxSize);
        gr_photo = new QGroupBox(page);
        gr_photo->setObjectName(QString::fromUtf8("gr_photo"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(gr_photo->sizePolicy().hasHeightForWidth());
        gr_photo->setSizePolicy(sizePolicy2);
        verticalLayout_2 = new QVBoxLayout(gr_photo);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        m_photo = new QLabel(gr_photo);
        m_photo->setObjectName(QString::fromUtf8("m_photo"));
        m_photo->setMinimumSize(QSize(140, 120));
        m_photo->setMaximumSize(QSize(140, 32767));
        m_photo->setFrameShape(QFrame::Box);
        m_photo->setLineWidth(2);
        m_photo->setAlignment(Qt::AlignCenter);

        horizontalLayout->addWidget(m_photo);


        verticalLayout_2->addLayout(horizontalLayout);

        m_photoid = new KComboBox(gr_photo);
        m_photoid->setObjectName(QString::fromUtf8("m_photoid"));

        verticalLayout_2->addWidget(m_photoid);


        right->addWidget(gr_photo);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        right->addItem(verticalSpacer);

        gr_buttons = new QGroupBox(page);
        gr_buttons->setObjectName(QString::fromUtf8("gr_buttons"));
        verticalLayout_3 = new QVBoxLayout(gr_buttons);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        m_disable = new QCheckBox(gr_buttons);
        m_disable->setObjectName(QString::fromUtf8("m_disable"));

        verticalLayout_3->addWidget(m_disable);

        m_expirationbtn = new KPushButton(gr_buttons);
        m_expirationbtn->setObjectName(QString::fromUtf8("m_expirationbtn"));

        verticalLayout_3->addWidget(m_expirationbtn);

        m_password = new KPushButton(gr_buttons);
        m_password->setObjectName(QString::fromUtf8("m_password"));

        verticalLayout_3->addWidget(m_password);


        right->addWidget(gr_buttons);


        top->addLayout(right);


        verticalLayout_5->addLayout(top);

        gr_fingerprint = new QGroupBox(page);
        gr_fingerprint->setObjectName(QString::fromUtf8("gr_fingerprint"));
        QSizePolicy sizePolicy3(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(gr_fingerprint->sizePolicy().hasHeightForWidth());
        gr_fingerprint->setSizePolicy(sizePolicy3);
        gr_fingerprint->setMinimumSize(QSize(0, 40));
        verticalLayout_4 = new QVBoxLayout(gr_fingerprint);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        verticalLayout_4->setSizeConstraint(QLayout::SetMinimumSize);
        m_fingerprint = new QLabel(gr_fingerprint);
        m_fingerprint->setObjectName(QString::fromUtf8("m_fingerprint"));
        sizePolicy3.setHeightForWidth(m_fingerprint->sizePolicy().hasHeightForWidth());
        m_fingerprint->setSizePolicy(sizePolicy3);
        m_fingerprint->setText(QString::fromUtf8(""));
        m_fingerprint->setTextInteractionFlags(Qt::TextSelectableByMouse);

        verticalLayout_4->addWidget(m_fingerprint);


        verticalLayout_5->addWidget(gr_fingerprint);


        retranslateUi(kgpgKeyInfo);

        QMetaObject::connectSlotsByName(kgpgKeyInfo);
    } // setupUi

    void retranslateUi(KDialog *kgpgKeyInfo)
    {
        kgpgKeyInfo->setWindowTitle(tr2i18n("Kgpg", 0));
        gr_properties->setTitle(tr2i18n("Key properties", 0));
        tl_id->setText(tr2i18n("Key ID:", 0));
        tl_comment->setText(tr2i18n("Comment:", 0));
        tl_creation->setText(tr2i18n("Creation:", 0));
        tl_expiration->setText(tr2i18n("Expiration:", 0));
        tl_trust->setText(tr2i18n("Trust:", 0));
        tl_owtrust->setText(tr2i18n("Owner trust:", 0));
        m_owtrust->clear();
        m_owtrust->insertItems(0, QStringList()
         << tr2i18n("I do not know", 0)
         << tr2i18n("I do NOT trust", 0)
         << tr2i18n("Marginally", 0)
         << tr2i18n("Fully", 0)
         << tr2i18n("Ultimately", 0)
        );
        tl_algorithm->setText(tr2i18n("Algorithm:", 0));
        tl_length->setText(tr2i18n("Length:", 0));
        tl_caps->setText(tr2i18n("Capabilities", 0));
        m_caps->setText(QString());
        gr_photo->setTitle(tr2i18n("Photo", 0));
#ifndef UI_QT_NO_WHATSTHIS
        m_photo->setWhatsThis(tr2i18n("<qt><b>Photo:</b><p>A photo can be included with a public key for extra security. The photo can be used as an additional method of authenticating the key. However, it should not be relied upon as the only form of authentication.</p></qt>", 0));
#endif // QT_NO_WHATSTHIS
        m_photo->setText(tr2i18n("No Photo", 0));
        gr_buttons->setTitle(QString());
        m_disable->setText(tr2i18n("Disable key", 0));
        m_expirationbtn->setText(tr2i18n("Change Expiration", 0));
        m_password->setText(tr2i18n("Change Passphrase", 0));
        gr_fingerprint->setTitle(tr2i18n("Fingerprint", 0));
    } // retranslateUi

};

namespace Ui {
    class kgpgKeyInfo: public Ui_kgpgKeyInfo {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KGPGKEYINFO_H

